# autogenerated from /usr/include/X11/keysymdef.h

keysyms = {
    'Greek_omicron': 0x7ef,
    'Uhornacute': 0x1001ee8,
    'Kcedilla': 0x3d3,
    'Georgian_san': 0x10010e1,
    'DongSign': 0x10020ab,
    'Hangul_AraeA': 0xef6,
    'MouseKeys_Enable': 0xfe76,
    'KP_Page_Up': 0xff9a,
    'Massyo': 0xff2c,
    'braille_dots_34567': 0x100287c,
    'Georgian_qar': 0x10010e7,
    'braille_dots_1234': 0x100280f,
    'Hangul_J_Kiyeog': 0xed4,
    'openstar': 0xae5,
    'hebrew_finalzade': 0xcf5,
    'Thai_leknung': 0xdf1,
    'hebrew_finalzadi': 0xcf5,
    'braille_dots_1238': 0x1002887,
    'lcedilla': 0x3b6,
    'Thai_soso': 0xdab,
    'foursubscript': 0x1002084,
    'Hangul_J_RieulPieub': 0xede,
    'Rcedilla': 0x3a3,
    'Serbian_dze': 0x6af,
    'StickyKeys_Enable': 0xfe75,
    'braille_dots_257': 0x1002852,
    'Armenian_ini': 0x100056b,
    'Hangul_J_Pieub': 0xee4,
    'Mabovedot': 0x1001e40,
    'downtack': 0xbc2,
    'braille_dots_258': 0x1002892,
    'Page_Down': 0xff56,
    'Cyrillic_ka_vertstroke': 0x100049d,
    'braille_dots_245678': 0x10028fa,
    'threesubscript': 0x1002083,
    'Scaron': 0x1a9,
    'Henkan_Mode': 0xff23,
    'G': 0x47,
    'Cacute': 0x1c6,
    'logicaland': 0x8de,
    'Pointer_DblClick_Dflt': 0xfeee,
    'gcedilla': 0x3bb,
    'braille_dots_12457': 0x100285b,
    'braille_dots_12456': 0x100283b,
    'braille_dots_12458': 0x100289b,
    'THORN': 0xde,
    'greaterthanequal': 0x8be,
    'Pointer_EnableKeys': 0xfef9,
    'Greek_upsilonaccent': 0x7b8,
    'dead_belowcircumflex': 0xfe69,
    'acircumflex': 0xe2,
    'ISO_Partial_Space_Left': 0xfe25,
    'Georgian_on': 0x10010dd,
    'k': 0x6b,
    'Ooblique': 0xd8,
    'Rcaron': 0x1d8,
    'Arabic_alef': 0x5c7,
    'Hangul_J_KkogjiDalrinIeung': 0xef9,
    'Agrave': 0xc0,
    'Home': 0xff50,
    'Greek_switch': 0xff7e,
    'Armenian_but': 0x100055d,
    'Cyrillic_en_descender': 0x10004a3,
    'Hangul_Dikeud': 0xea7,
    'Greek_eta': 0x7e7,
    'Acircumflextilde': 0x1001eaa,
    'ccaron': 0x1e8,
    'Hstroke': 0x2a1,
    'Arabic_hamza_above': 0x1000654,
    'F10': 0xffc7,
    'Thai_thothahan': 0xdb7,
    'leftsinglequotemark': 0xad0,
    'zabovedot': 0x1bf,
    'Ukrainian_IE': 0x6b4,
    'NairaSign': 0x10020a6,
    'braille_dots_2357': 0x1002856,
    'KP_Next': 0xff9b,
    'therefore': 0x8c0,
    'Mae_Koho': 0xff3e,
    'hebrew_dalet': 0xce3,
    'Cyrillic_er': 0x6d2,
    'Hangul_J_Jieuj': 0xee9,
    'V': 0x56,
    'Overlay1_Enable': 0xfe78,
    'rightt': 0x9f5,
    'Hangul_Jieuj': 0xeb8,
    'partdifferential': 0x1002202,
    'mu': 0xb5,
    'Cyrillic_SCHWA': 0x10004d8,
    'braille_dot_10': 0xfffa,
    'Hangul_Codeinput': 0xff37,
    'Armenian_DA': 0x1000534,
    'lowrightcorner': 0x9ea,
    'Greek_OMEGA': 0x7d9,
    'Ohorngrave': 0x1001edc,
    'Hangul_PreHanja': 0xff3a,
    'currency': 0xa4,
    'braille_dots_124568': 0x10028bb,
    'braille_dots_124567': 0x100287b,
    'Uhook': 0x1001ee6,
    'Shift_Lock': 0xffe6,
    'Muhenkan': 0xff22,
    'eng': 0x3bf,
    'Cyrillic_DZHE': 0x6bf,
    'Hangul_J_YeorinHieuh': 0xefa,
    'A': 0x41,
    'Thai_nonu': 0xdb9,
    'Armenian_VO': 0x1000548,
    'L6': 0xffcd,
    'L7': 0xffce,
    'L4': 0xffcb,
    'L5': 0xffcc,
    'L2': 0xffc9,
    'L3': 0xffca,
    'L1': 0xffc8,
    'L8': 0xffcf,
    'L9': 0xffd0,
    'ISO_Partial_Line_Down': 0xfe24,
    'KP_Up': 0xff97,
    'Cyrillic_YERU': 0x6f9,
    'Dstroke': 0x1d0,
    'Cyrillic_en': 0x6ce,
    'Hangul_SunkyeongeumMieum': 0xef0,
    'includedin': 0x8da,
    'checkerboard': 0x9e1,
    'Pointer_Button_Dflt': 0xfee8,
    'hebrew_kaph': 0xceb,
    'approxeq': 0x1002248,
    'Thai_nikhahit': 0xded,
    'ograve': 0xf2,
    'Georgian_hie': 0x10010f2,
    'Armenian_lyun': 0x100056c,
    'kana_NU': 0x4c7,
    'kana_NI': 0x4c6,
    'kana_NO': 0x4c9,
    'kana_NA': 0x4c5,
    'Hangul_J_SsangSios': 0xee7,
    'kana_NE': 0x4c8,
    'Armenian_tso': 0x1000581,
    'Hangul_J_Khieuq': 0xeeb,
    'Armenian_tsa': 0x100056e,
    'Cyrillic_ZE': 0x6fa,
    'otilde': 0xf5,
    'braille_dots_15': 0x1002811,
    'braille_dots_14': 0x1002809,
    'braille_dots_17': 0x1002841,
    'braille_dots_16': 0x1002821,
    'Abrevehook': 0x1001eb2,
    'braille_dots_12': 0x1002803,
    'Arabic_fatha': 0x5ee,
    'guillemotright': 0xbb,
    'Armenian_je': 0x100057b,
    'ISO_Level5_Lock': 0xfe13,
    'onethird': 0xab0,
    'braille_dots_15678': 0x10028f1,
    'toprightsqbracket': 0x8a9,
    'l': 0x6c,
    'dead_doubleacute': 0xfe59,
    'Codeinput': 0xff37,
    'notsign': 0xac,
    'dead_belowdiaeresis': 0xfe6c,
    'braille_dots_3458': 0x100289c,
    'braille_dots_3456': 0x100283c,
    'braille_dots_3457': 0x100285c,
    'Yhook': 0x1001ef6,
    'braille_dots_145678': 0x10028f9,
    'braille_dots_4678': 0x10028e8,
    'Armenian_re': 0x1000580,
    'Thai_yoying': 0xdad,
    'quoteright': 0x27,
    'braille_dots_248': 0x100288a,
    'ucircumflex': 0xfb,
    'braille_dots_245': 0x100281a,
    'braille_dots_247': 0x100284a,
    'PreviousCandidate': 0xff3e,
    'Arabic_tehmarbuta': 0x5c9,
    'Thai_thanthakhat': 0xdec,
    'Arabic_yeh_baree': 0x10006d2,
    'W': 0x57,
    'dead_psili': 0xfe64,
    'uhornacute': 0x1001ee9,
    'logicalor': 0x8df,
    'downstile': 0xbc4,
    'wacute': 0x1001e83,
    'notelementof': 0x1002209,
    'braille_dots_12467': 0x100286b,
    'Zabovedot': 0x1af,
    'Thai_dodek': 0xdb4,
    'Thai_lekpaet': 0xdf8,
    'braille_dots_123678': 0x10028e7,
    'ballotcross': 0xaf4,
    'abrevetilde': 0x1001eb5,
    'Georgian_jhan': 0x10010ef,
    'Cyrillic_softsign': 0x6d8,
    'emfilledcircle': 0xade,
    'Hangul_PreviousCandidate': 0xff3e,
    'Kanji_Bangou': 0xff37,
    'Ukranian_YI': 0x6b7,
    'hebrew_gimmel': 0xce2,
    'Greek_iotadieresis': 0x7b5,
    'Greek_IOTAdieresis': 0x7a5,
    'ocircumflextilde': 0x1001ed7,
    'B': 0x42,
    'Greek_xi': 0x7ee,
    'ediaeresis': 0xeb,
    'rightopentriangle': 0xacd,
    'Armenian_nu': 0x1000576,
    'Cyrillic_zhe': 0x6d6,
    'twofifths': 0xab3,
    'Cyrillic_HA_descender': 0x10004b2,
    'botrightsummation': 0x8b6,
    'Hangul_J_RieulKiyeog': 0xedc,
    'uhornbelowdot': 0x1001ef1,
    'minus': 0x2d,
    'tcaron': 0x1bb,
    'hebrew_doublelowline': 0xcdf,
    'soliddiamond': 0x9e0,
    'hebrew_zain': 0xce6,
    'Armenian_SHA': 0x1000547,
    'braille_dots_2678': 0x10028e2,
    'hebrew_finalmem': 0xced,
    'Hangul_RieulPhieuf': 0xeaf,
    'Gabovedot': 0x2d5,
    'Hangul_J_RieulPhieuf': 0xee1,
    'Uacute': 0xda,
    'onesubscript': 0x1002081,
    'braille_dots_135678': 0x10028f5,
    'Arabic_ra': 0x5d1,
    'braille_dots_1378': 0x10028c5,
    'Greek_upsilondieresis': 0x7b9,
    'Arabic_comma': 0x5ac,
    'KP_F3': 0xff93,
    'KP_F2': 0xff92,
    'KP_F1': 0xff91,
    'KP_F4': 0xff94,
    'Armenian_ke': 0x1000584,
    'grave': 0x60,
    'Ocircumflex': 0xd4,
    'm': 0x6d,
    'lstroke': 0x1b3,
    'braille_dots_1368': 0x10028a5,
    'Ukranian_JE': 0x6b4,
    'Hangul_WEO': 0xecd,
    'lowleftcorner': 0x9ed,
    'F23': 0xffd4,
    'F22': 0xffd3,
    'F21': 0xffd2,
    'F20': 0xffd1,
    'F27': 0xffd8,
    'F26': 0xffd7,
    'F25': 0xffd6,
    'Atilde': 0xc3,
    'F29': 0xffda,
    'F28': 0xffd9,
    'ybelowdot': 0x1001ef5,
    'hcircumflex': 0x2b6,
    'Hangul_Khieuq': 0xebb,
    'leftanglebracket': 0xabc,
    'rcaron': 0x1f8,
    'KP_Insert': 0xff9e,
    'Acircumflexhook': 0x1001ea8,
    'seveneighths': 0xac6,
    'Eacute': 0xc9,
    'Lbelowdot': 0x1001e36,
    'Thai_chochoe': 0xdac,
    'cacute': 0x1e6,
    'braille_dots_4': 0x1002808,
    'acircumflexhook': 0x1001ea9,
    'Hangul_End': 0xff33,
    'Arabic_tah': 0x5d7,
    'kana_openingbracket': 0x4a2,
    'thinspace': 0xaa7,
    'Serbian_dje': 0x6a1,
    'bar': 0x7c,
    'rightanglebracket': 0xabe,
    'Cyrillic_u_macron': 0x10004ef,
    'Thai_sosua': 0xdca,
    'dead_abovering': 0xfe58,
    'numerosign': 0x6b0,
    'dead_currency': 0xfe6f,
    'braille_dots_128': 0x1002883,
    'Thai_lekha': 0xdf5,
    'Hangul_J_Nieun': 0xed7,
    'braille_dots_123': 0x1002807,
    'L10': 0xffd1,
    'braille_dots_125': 0x1002813,
    'Cabovedot': 0x2c5,
    'braille_dots_127': 0x1002843,
    'Armenian_KEN': 0x100053f,
    'mabovedot': 0x1001e41,
    'Thai_rorua': 0xdc3,
    'Sabovedot': 0x1001e60,
    'hebrew_taw': 0xcfa,
    'voicedsound': 0x4de,
    'atilde': 0xe3,
    'Arabic_alefmaksura': 0x5e9,
    'Arabic_jeem': 0x5cc,
    'hebrew_taf': 0xcfa,
    'C': 0x43,
    'lessthanequal': 0x8bc,
    'Jcircumflex': 0x2ac,
    'Arabic_zah': 0x5d8,
    'braille_dots_3467': 0x100286c,
    'Hangul_RieulSios': 0xead,
    'ISO_Level5_Shift': 0xfe11,
    'braille_dots_3468': 0x10028ac,
    'braille_dots_45': 0x1002818,
    'Udoubleacute': 0x1db,
    'braille_dots_27': 0x1002842,
    'leftradical': 0x8a1,
    'braille_dots_238': 0x1002886,
    'Cyrillic_hardsign': 0x6df,
    'braille_dots_234': 0x100280e,
    'braille_dots_235': 0x1002816,
    'braille_dots_236': 0x1002826,
    'braille_dots_237': 0x1002846,
    'Hangul_AE': 0xec0,
    'Egrave': 0xc8,
    '3270_ExSelect': 0xfd1b,
    'igrave': 0xec,
    'Thai_kokai': 0xda1,
    'ETH': 0xd0,
    '3270_Copy': 0xfd15,
    'Hangul_J_KiyeogSios': 0xed6,
    'Arabic_dammatan': 0x5ec,
    'union': 0x8dd,
    'Pointer_DownLeft': 0xfee6,
    'braille_dots_346': 0x100282c,
    'braille_dots_347': 0x100284c,
    'braille_dots_348': 0x100288c,
    'Pointer_DblClick5': 0xfef3,
    'Pointer_DblClick4': 0xfef2,
    'braille_dots_12478': 0x10028cb,
    'Pointer_DblClick1': 0xfeef,
    'Pointer_DblClick3': 0xfef1,
    'Pointer_DblClick2': 0xfef0,
    'Hangul_WE': 0xece,
    '3270_Enter': 0xfd1e,
    'KP_Page_Down': 0xff9b,
    'ISO_Group_Shift': 0xff7e,
    'Macedonia_DSE': 0x6b5,
    'guillemotleft': 0xab,
    'Ecircumflexacute': 0x1001ebe,
    'Arabic_thal': 0x5d0,
    'n': 0x6e,
    'braille_dots_1567': 0x1002871,
    'nobreakspace': 0xa0,
    'Menu': 0xff67,
    'Greek_etaaccent': 0x7b3,
    'Arabic_jeh': 0x1000698,
    'dead_caron': 0xfe5a,
    'figdash': 0xabb,
    'fivesuperior': 0x1002075,
    'Armenian_JE': 0x100054b,
    'periodcentered': 0xb7,
    'Cyrillic_yeru': 0x6d9,
    'leftarrow': 0x8fb,
    'MultipleCandidate': 0xff3d,
    'Greek_mu': 0x7ec,
    'Hangul_RieulMieum': 0xeab,
    'Georgian_shin': 0x10010e8,
    'uhook': 0x1001ee7,
    'sabovedot': 0x1001e61,
    'braille_dots_13567': 0x1002875,
    'Thai_phophan': 0xdbe,
    'topt': 0x9f7,
    'Georgian_ban': 0x10010d1,
    'Greek_GAMMA': 0x7c3,
    'Num_Lock': 0xff7f,
    'Hangul_RieulKiyeog': 0xeaa,
    'Y': 0x59,
    'KP_Delete': 0xff9f,
    'hebrew_het': 0xce7,
    'Arabic_veh': 0x10006a4,
    'hebrew_lamed': 0xcec,
    'tcedilla': 0x1fe,
    'Arabic_9': 0x1000669,
    'Arabic_8': 0x1000668,
    'ISO_Move_Line_Up': 0xfe21,
    'Armenian_FE': 0x1000556,
    'Arabic_1': 0x1000661,
    'Arabic_0': 0x1000660,
    'Arabic_3': 0x1000663,
    'Arabic_2': 0x1000662,
    'Arabic_5': 0x1000665,
    'Arabic_4': 0x1000664,
    'Arabic_7': 0x1000667,
    'Arabic_6': 0x1000666,
    'plusminus': 0xb1,
    'yen': 0xa5,
    'Cyrillic_SOFTSIGN': 0x6f8,
    'kana_YA': 0x4d4,
    'Armenian_ZA': 0x1000536,
    'ocircumflexbelowdot': 0x1001ed9,
    'Hangul_J_PieubSios': 0xee5,
    'D': 0x44,
    'F30': 0xffdb,
    'F31': 0xffdc,
    'F32': 0xffdd,
    'F33': 0xffde,
    'F34': 0xffdf,
    'F35': 0xffe0,
    'Greek_kappa': 0x7ea,
    'Wdiaeresis': 0x1001e84,
    'lcaron': 0x1b5,
    'Cyrillic_KA_descender': 0x100049a,
    'ISO_Emphasize': 0xfe32,
    '3270_CursorSelect': 0xfd1c,
    'aogonek': 0x1b1,
    'Cyrillic_SHCHA': 0x6fd,
    'Thai_honokhuk': 0xdce,
    'Cyrillic_shha': 0x10004bb,
    'obarred': 0x1000275,
    'SingleCandidate': 0xff3c,
    'Thorn': 0xde,
    'leftt': 0x9f4,
    'braille_dots_23457': 0x100285e,
    'braille_dots_23456': 0x100283e,
    'zcaron': 0x1be,
    'sevensuperior': 0x1002077,
    'braille_dots_137': 0x1002845,
    'Armenian_LYUN': 0x100053c,
    'Hangul_J_Mieum': 0xee3,
    'braille_dots_134': 0x100280d,
    'Cyrillic_JE': 0x6b8,
    'Arabic_madda_above': 0x1000653,
    'ohook': 0x1001ecf,
    'o': 0x6f,
    'AccessX_Feedback_Enable': 0xfe71,
    'Greek_gamma': 0x7e3,
    'plus': 0x2b,
    'Greek_KAPPA': 0x7ca,
    'ydiaeresis': 0xff,
    'Hangul_RieulYeorinHieuh': 0xeef,
    'Greek_IOTA': 0x7c9,
    'Eisu_toggle': 0xff30,
    'Pabovedot': 0x1001e56,
    'dstroke': 0x1f0,
    'braille_dots_3678': 0x10028e4,
    'abelowdot': 0x1001ea1,
    'Cyrillic_VE': 0x6f7,
    'Hiragana': 0xff25,
    'topleftradical': 0x8a2,
    'braille_dots_3478': 0x10028cc,
    'acircumflexbelowdot': 0x1001ead,
    'ohorngrave': 0x1001edd,
    'checkmark': 0xaf3,
    'approximate': 0x8c8,
    'Break': 0xff6b,
    'Hangul_J_SsangKiyeog': 0xed5,
    'hstroke': 0x2b1,
    'egrave': 0xe8,
    '3270_EraseEOF': 0xfd06,
    'Ydiaeresis': 0x13be,
    'Z': 0x5a,
    'Kana_Shift': 0xff2e,
    'Left': 0xff51,
    'Ohorntilde': 0x1001ee0,
    'Cyrillic_lje': 0x6a9,
    'kana_RU': 0x4d9,
    'hairspace': 0xaa8,
    'kana_RO': 0x4db,
    'Thai_baht': 0xddf,
    'braille_dots_357': 0x1002854,
    'Greek_alphaaccent': 0x7b1,
    'kana_RI': 0x4d8,
    'Thai_thonangmontho': 0xdb1,
    'kana_RE': 0x4da,
    'braille_dots_358': 0x1002894,
    'kana_RA': 0x4d7,
    'nacute': 0x1f1,
    'horizlinescan9': 0x9f3,
    'horizlinescan7': 0x9f2,
    'horizlinescan5': 0x9f1,
    'horizlinescan3': 0x9f0,
    'upstile': 0xbd3,
    'horizlinescan1': 0x9ef,
    'Thai_saraaa': 0xdd2,
    'Thai_saraae': 0xde1,
    'Georgian_vin': 0x10010d5,
    'Thai_saraam': 0xdd3,
    'Begin': 0xff58,
    'nl': 0x9e8,
    'Iacute': 0xcd,
    'semivoicedsound': 0x4df,
    'Greek_PSI': 0x7d8,
    'Armenian_separation_mark': 0x100055d,
    'Pointer_UpRight': 0xfee5,
    'enopensquarebullet': 0xae1,
    'Hangul_AraeAE': 0xef7,
    'onefifth': 0xab2,
    'Armenian_BEN': 0x1000532,
    'E': 0x45,
    'Cyrillic_U': 0x6f5,
    'topvertsummationconnector': 0x8b3,
    'asterisk': 0x2a,
    'opentribulletdown': 0xae4,
    'Arabic_noon_ghunna': 0x10006ba,
    'Cyrillic_O': 0x6ef,
    'Cyrillic_I': 0x6e9,
    'Cyrillic_E': 0x6fc,
    'Cyrillic_A': 0x6e1,
    'wgrave': 0x1001e81,
    'Cyrillic_u': 0x6d5,
    'braille_blank': 0x1002800,
    'Cyrillic_o': 0x6cf,
    'Cyrillic_i': 0x6c9,
    'Cyrillic_e': 0x6dc,
    'Hangul_Start': 0xff32,
    'Cyrillic_a': 0x6c1,
    'Hcircumflex': 0x2a6,
    'Alt_R': 0xffea,
    'Hangul_SsangJieuj': 0xeb9,
    'Greek_ALPHA': 0x7c1,
    'Alt_L': 0xffe9,
    'kana_CHI': 0x4c1,
    'dabovedot': 0x1001e0b,
    'Thai_maiyamok': 0xde6,
    '0': 0x30,
    'braille_dots_1358': 0x1002895,
    'Touroku': 0xff2b,
    'Pointer_DfltBtnPrev': 0xfefc,
    'braille_dots_1357': 0x1002855,
    'idotless': 0x2b9,
    'Arabic_noon': 0x5e6,
    'ISO_Set_Margin_Right': 0xfe28,
    'division': 0xf7,
    'braille_dots_24678': 0x10028ea,
    'slash': 0x2f,
    'ocaron': 0x10001d2,
    'Romaji': 0xff24,
    'Hangul_SunkyeongeumPieub': 0xef1,
    'braille_dots_234578': 0x10028de,
    'Hangul_Jeonja': 0xff38,
    'p': 0x70,
    'Tab': 0xff09,
    'leftshoe': 0xbda,
    'hebrew_qoph': 0xcf7,
    'Arabic_hamzaonalef': 0x5c3,
    'Serbian_TSHE': 0x6bb,
    'braille_dots_138': 0x1002885,
    'Armenian_e': 0x1000567,
    'Cyrillic_KA': 0x6eb,
    'braille_dots_2345678': 0x10028fe,
    'Next_Virtual_Screen': 0xfed2,
    'Cyrillic_ghe_bar': 0x1000493,
    'dead_semivoiced_sound': 0xfe5f,
    'ntilde': 0xf1,
    'braille_dots_1268': 0x10028a3,
    'ampersand': 0x26,
    'Armenian_E': 0x1000537,
    'Armenian_O': 0x1000555,
    'braille_dots_136': 0x1002825,
    'crossinglines': 0x9ee,
    'braille_dots_135': 0x1002815,
    'VoidSymbol': 0xffffff,
    'braille_dots_34568': 0x10028bc,
    'braille_dots_1267': 0x1002863,
    'Armenian_paruyk': 0x100055e,
    'Greek_alpha': 0x7e1,
    'Abrevetilde': 0x1001eb4,
    'fabovedot': 0x1001e1f,
    'ISO_Partial_Space_Right': 0xfe26,
    'Abreve': 0x1c3,
    'braille_dots_23468': 0x10028ae,
    'Georgian_kan': 0x10010d9,
    'Thai_topatak': 0xdaf,
    'ocircumflex': 0xf4,
    'braille_dots_47': 0x1002848,
    'braille_dots_13458': 0x100289d,
    'asciitilde': 0x7e,
    'Lacute': 0x1c5,
    'marker': 0xabf,
    'braille_dots_13456': 0x100283d,
    'braille_dots_13457': 0x100285d,
    'ohorntilde': 0x1001ee1,
    'hebrew_he': 0xce4,
    'kana_SU': 0x4bd,
    'Thai_phinthu': 0xdda,
    'kana_SO': 0x4bf,
    'kana_SE': 0x4be,
    'Armenian_hyphen': 0x100058a,
    'dead_doublegrave': 0xfe66,
    'KP_Add': 0xffab,
    'Arabic_damma': 0x5ef,
    'Cyrillic_shorti': 0x6ca,
    'F': 0x46,
    'club': 0xaec,
    'Thai_saraaimaimuan': 0xde3,
    'Pointer_Accelerate': 0xfefa,
    'Arabic_hamza_below': 0x1000655,
    'Adiaeresis': 0xc4,
    'kana_MA': 0x4cf,
    'Cyrillic_YA': 0x6f1,
    'kana_MI': 0x4d0,
    'kana_MO': 0x4d3,
    'KP_Enter': 0xff8d,
    'Down': 0xff54,
    'Cyrillic_YU': 0x6e0,
    'Hangul_RieulPieub': 0xeac,
    'Thai_sorusi': 0xdc9,
    'heart': 0xaee,
    'braille_dots_1345': 0x100281d,
    'musicalflat': 0xaf6,
    'rightsinglequotemark': 0xad1,
    'braille_dots_13678': 0x10028e5,
    'backslash': 0x5c,
    'hebrew_teth': 0xce8,
    'braille_dots_34678': 0x10028ec,
    'idiaeresis': 0xef,
    'braille_dots_12678': 0x10028e3,
    '1': 0x31,
    'braille_dots_367': 0x1002864,
    'Greek_upsilonaccentdieresis': 0x7ba,
    'hebrew_mem': 0xcee,
    'ygrave': 0x1001ef3,
    'Arabic_farsi_yeh': 0x10006cc,
    'Thai_thothong': 0xdb8,
    'braille_dots_1234568': 0x10028bf,
    'Cyrillic_KA_vertstroke': 0x100049c,
    'braille_dots_1234567': 0x100287f,
    'downshoe': 0xbd6,
    'Lstroke': 0x1a3,
    'braille_dot_9': 0xfff9,
    'braille_dot_8': 0xfff8,
    'dintegral': 0x100222c,
    'braille_dot_2': 0xfff2,
    'braille_dot_1': 0xfff1,
    'braille_dot_7': 0xfff7,
    'braille_dot_6': 0xfff6,
    'braille_dot_5': 0xfff5,
    'braille_dot_4': 0xfff4,
    'Cyrillic_I_macron': 0x10004e2,
    'Henkan': 0xff23,
    'uparrow': 0x8fc,
    'q': 0x71,
    'Odiaeresis': 0xd6,
    'Hangul_J_RieulSios': 0xedf,
    'Arabic_beh': 0x5c8,
    'Thai_ngongu': 0xda7,
    'braille_dots_134678': 0x10028ed,
    'Arabic_sheen': 0x5d4,
    'Hangul': 0xff31,
    'acircumflextilde': 0x1001eab,
    'Georgian_zen': 0x10010d6,
    'Control_R': 0xffe4,
    'gcircumflex': 0x2f8,
    'Cyrillic_CHE_vertstroke': 0x10004b8,
    'Armenian_sha': 0x1000577,
    'Control_L': 0xffe3,
    'Armenian_pyur': 0x1000583,
    'R4': 0xffd5,
    'R5': 0xffd6,
    'R6': 0xffd7,
    'R7': 0xffd8,
    'ecircumflex': 0xea,
    'R1': 0xffd2,
    'R2': 0xffd3,
    'R3': 0xffd4,
    'dead_invertedbreve': 0xfe6d,
    'R8': 0xffd9,
    'R9': 0xffda,
    'Georgian_in': 0x10010d8,
    'ccircumflex': 0x2e6,
    'foursuperior': 0x1002074,
    'Odoubleacute': 0x1d5,
    'uhornhook': 0x1001eed,
    'hebrew_finalkaph': 0xcea,
    'Ncedilla': 0x3d1,
    'braille_dots_1348': 0x100288d,
    'KP_Tab': 0xff89,
    'ebelowdot': 0x1001eb9,
    'Hangul_J_RieulMieum': 0xedd,
    'braille_dots_1346': 0x100282d,
    'braille_dots_1347': 0x100284d,
    'Zenkaku': 0xff28,
    'Greek_iotaaccentdieresis': 0x7b6,
    'braille_dots_234567': 0x100287e,
    'braille_dots_234568': 0x10028be,
    'ISO_Fast_Cursor_Down': 0xfe2f,
    'filledrectbullet': 0xadb,
    'Hangul_PieubSios': 0xeb4,
    'similarequal': 0x8c9,
    'space': 0x20,
    'Cyrillic_ze': 0x6da,
    'dead_belowmacron': 0xfe68,
    'Hangul_J_Phieuf': 0xeed,
    'twosuperior': 0xb2,
    'braille_dots_1235': 0x1002817,
    'braille_dots_1236': 0x1002827,
    'braille_dots_1237': 0x1002847,
    'dead_abovecomma': 0xfe64,
    'hebrew_gimel': 0xce2,
    'ENG': 0x3bd,
    'Arabic_khah': 0x5ce,
    'ISO_Level2_Latch': 0xfe02,
    'quoteleft': 0x60,
    'F18': 0xffcf,
    'F19': 0xffd0,
    'F12': 0xffc9,
    'F13': 0xffca,
    'Serbian_je': 0x6a8,
    'F11': 0xffc8,
    'F16': 0xffcd,
    'F17': 0xffce,
    'F14': 0xffcb,
    'F15': 0xffcc,
    'Georgian_las': 0x10010da,
    'ISO_Fast_Cursor_Right': 0xfe2d,
    'Hangul_KiyeogSios': 0xea3,
    'kana_fullstop': 0x4a1,
    'Armenian_verjaket': 0x1000589,
    'Hangul_Ieung': 0xeb7,
    'Greek_DELTA': 0x7c4,
    'Pointer_Right': 0xfee1,
    'Ubreve': 0x2dd,
    'Ukrainian_ghe_with_upturn': 0x6ad,
    'Georgian_jil': 0x10010eb,
    'Ycircumflex': 0x1000176,
    'braille_dots_2457': 0x100285a,
    'braille_dots_2456': 0x100283a,
    'Shift_R': 0xffe2,
    'elementof': 0x1002208,
    'braille_dots_2458': 0x100289a,
    '2': 0x32,
    'abovedot': 0x1ff,
    'Armenian_ken': 0x100056f,
    'Shift_L': 0xffe1,
    'Ukrainian_GHE_WITH_UPTURN': 0x6bd,
    'leftdoublequotemark': 0xad2,
    'iacute': 0xed,
    'braille_dots_23478': 0x10028ce,
    'squareroot': 0x100221a,
    'Cyrillic_HA': 0x6e8,
    'Thai_maitri': 0xdea,
    'Tabovedot': 0x1001e6a,
    'Armenian_yentamna': 0x100058a,
    'Ytilde': 0x1001ef8,
    'Thai_ru': 0xdc4,
    'Thai_phophung': 0xdbc,
    'em4space': 0xaa4,
    'Armenian_dza': 0x1000571,
    'braille_dots_23678': 0x10028e6,
    'Uhorntilde': 0x1001eee,
    'r': 0x72,
    'doubbaselinedot': 0xaaf,
    '3270_Rule': 0xfd14,
    'Cyrillic_TE': 0x6f4,
    'Armenian_KE': 0x1000554,
    'hebrew_samekh': 0xcf1,
    'Ucircumflex': 0xdb,
    'Cyrillic_schwa': 0x10004d9,
    'Armenian_exclam': 0x100055c,
    'abreve': 0x1e3,
    '3270_Reset': 0xfd08,
    'Hangul_YeorinHieuh': 0xef5,
    'Armenian_KHE': 0x100053d,
    'Ohook': 0x1001ece,
    'onehalf': 0xbd,
    'numbersign': 0x23,
    'Greek_XI': 0x7ce,
    'Fabovedot': 0x1001e1e,
    'emacron': 0x3ba,
    'KP_Separator': 0xffac,
    'multiply': 0xd7,
    'Greek_OMICRON': 0x7cf,
    'Ocircumflexhook': 0x1001ed4,
    'braille_dots_378': 0x10028c4,
    'Armenian_pe': 0x100057a,
    'braille_dots_1234578': 0x10028df,
    'hebrew_shin': 0xcf9,
    'Pointer_DownRight': 0xfee7,
    'kana_tu': 0x4af,
    'Sacute': 0x1a6,
    'Greek_IOTAdiaeresis': 0x7a5,
    'AccessX_Enable': 0xfe70,
    'onequarter': 0xbc,
    'Cyrillic_shcha': 0x6dd,
    'H': 0x48,
    'gcaron': 0x10001e7,
    'downarrow': 0x8fe,
    'Greek_SIGMA': 0x7d2,
    'Armenian_GIM': 0x1000533,
    'Right': 0xff53,
    'uhorntilde': 0x1001eef,
    'braille_dots_568': 0x10028b0,
    'ColonSign': 0x10020a1,
    'ISO_Next_Group_Lock': 0xfe09,
    'braille_dots_567': 0x1002870,
    'MouseKeys_Accel_Enable': 0xfe77,
    'Hangul_Tieut': 0xebc,
    'Ccaron': 0x1c8,
    'Arabic_fullstop': 0x10006d4,
    'Farsi_1': 0x10006f1,
    'Farsi_0': 0x10006f0,
    'Farsi_3': 0x10006f3,
    'Farsi_2': 0x10006f2,
    'Farsi_5': 0x10006f5,
    'Farsi_4': 0x10006f4,
    'Farsi_7': 0x10006f7,
    'Farsi_6': 0x10006f6,
    'Farsi_9': 0x10006f9,
    'Farsi_8': 0x10006f8,
    'Serbian_JE': 0x6b8,
    'dead_dasia': 0xfe65,
    'Thai_sarauu': 0xdd9,
    'braille_dots_147': 0x1002849,
    '3': 0x33,
    'Arabic_semicolon': 0x5bb,
    'braille_dots_458': 0x1002898,
    'Thai_saraue': 0xdd6,
    'braille_dots_356': 0x1002834,
    'Greek_beta': 0x7e2,
    'FFrancSign': 0x10020a3,
    'Greek_zeta': 0x7e6,
    'Tcaron': 0x1ab,
    'braille_dots_457': 0x1002858,
    'enopencircbullet': 0xae0,
    'Greek_nu': 0x7ed,
    '3270_Left2': 0xfd04,
    'braille_dots_1245': 0x100281b,
    's': 0x73,
    'braille_dots_1246': 0x100282b,
    'Escape': 0xff1b,
    'zerosubscript': 0x1002080,
    'braille_dots_1248': 0x100288b,
    'Georgian_chin': 0x10010e9,
    'Ihook': 0x1001ec8,
    'Idiaeresis': 0xcf,
    'Utilde': 0x3dd,
    'period': 0x2e,
    'Cyrillic_IE': 0x6e5,
    'colon': 0x3a,
    'Cyrillic_IO': 0x6b3,
    'Hangul_WAE': 0xec9,
    'caret': 0xafc,
    'Ecircumflex': 0xca,
    'semicolon': 0x3b,
    'KP_Divide': 0xffaf,
    'ihook': 0x1001ec9,
    '3270_Duplicate': 0xfd01,
    'Hangul_J_RieulTieut': 0xee0,
    'Thai_lekchet': 0xdf7,
    'ohorn': 0x10001a1,
    'braille_dots_13': 0x1002805,
    'Arabic_ha': 0x5e7,
    'breve': 0x1a2,
    'CruzeiroSign': 0x10020a2,
    'Uhornhook': 0x1001eec,
    'ISO_Level3_Shift': 0xfe03,
    'kappa': 0x3a2,
    'Pointer_Up': 0xfee2,
    'braille_dots_18': 0x1002881,
    'braille_dots_1367': 0x1002865,
    'Greek_delta': 0x7e4,
    'Hangul_J_Sios': 0xee6,
    'Thai_maitaikhu': 0xde7,
    'threequarters': 0xbe,
    'Armenian_GHAT': 0x1000542,
    'Armenian_MEN': 0x1000544,
    'telephone': 0xaf9,
    'Cyrillic_NJE': 0x6ba,
    'ugrave': 0xf9,
    'braille_dots_167': 0x1002861,
    'braille_dots_13478': 0x10028cd,
    'fiveeighths': 0xac5,
    '3270_Test': 0xfd0d,
    'ISO_Discontinuous_Underline': 0xfe31,
    'hebrew_tet': 0xce8,
    'SlowKeys_Enable': 0xfe73,
    'braille_dots_1247': 0x100284b,
    'Uhorngrave': 0x1001eea,
    'braille_dots_345678': 0x10028fc,
    'sterling': 0xa3,
    'Hangul_YEO': 0xec5,
    'topintegral': 0x8a4,
    'Hiragana_Katakana': 0xff27,
    'I': 0x49,
    'Super_R': 0xffec,
    'Clear': 0xff0b,
    'Greek_lambda': 0x7eb,
    '3270_Right2': 0xfd03,
    'apostrophe': 0x27,
    'Eth': 0xd0,
    'Ocircumflexacute': 0x1001ed0,
    'Thai_lekhok': 0xdf6,
    'Hangul_EU': 0xed1,
    'ncaron': 0x1f2,
    'Hangul_SunkyeongeumPhieuf': 0xef4,
    'Hangul_EO': 0xec3,
    'Cyrillic_GHE_bar': 0x1000492,
    'Hangul_Hanja': 0xff34,
    'zstroke': 0x10001b6,
    'Arabic_feh': 0x5e1,
    'sixsubscript': 0x1002086,
    'kana_SHI': 0x4bc,
    'Thai_maihanakat': 0xdd1,
    'Hangul_YA': 0xec1,
    'Hangul_YE': 0xec6,
    'Hangul_YI': 0xed2,
    'Hangul_YO': 0xecb,
    'Cyrillic_ha_descender': 0x10004b3,
    '4': 0x34,
    'dead_belowcomma': 0xfe6e,
    'hebrew_aleph': 0xce0,
    'Greek_sigma': 0x7f2,
    'Hangul_Mieum': 0xeb1,
    'Thai_sosala': 0xdc8,
    'Greek_phi': 0x7f6,
    'Greek_rho': 0x7f1,
    'Wacute': 0x1001e82,
    'oslash': 0xf8,
    'kana_comma': 0x4a4,
    'Greek_EPSILON': 0x7c5,
    'Greek_MU': 0x7cc,
    't': 0x74,
    'tabovedot': 0x1001e6b,
    'Georgian_an': 0x10010d0,
    'hebrew_daleth': 0xce3,
    'scircumflex': 0x2fe,
    'BounceKeys_Enable': 0xfe74,
    'braille_dots_2367': 0x1002866,
    'Thai_leksi': 0xdf4,
    'braille_dots_1458': 0x1002899,
    'Cyrillic_je': 0x6a8,
    'dead_acute': 0xfe51,
    'eogonek': 0x1ea,
    'Umacron': 0x3de,
    'braille_dots_1235678': 0x10028f7,
    'punctspace': 0xaa6,
    'Hangul_Banja': 0xff39,
    'braille_dots_578': 0x10028d0,
    'Armenian_at': 0x1000568,
    'seconds': 0xad7,
    '3270_BackTab': 0xfd05,
    'Greek_horizbar': 0x7af,
    'etilde': 0x1001ebd,
    'dead_perispomeni': 0xfe53,
    'toprightparens': 0x8ad,
    'oe': 0x13bd,
    'SCHWA': 0x100018f,
    'Uring': 0x1d9,
    'leftopentriangle': 0xacc,
    'Greek_UPSILONaccent': 0x7a8,
    'dead_ogonek': 0xfe5c,
    'Katakana': 0xff26,
    'dagger': 0xaf1,
    'leftmiddlecurlybrace': 0x8af,
    'eacute': 0xe9,
    'dead_cedilla': 0xfe5b,
    'parenleft': 0x28,
    'braille_dots_256': 0x1002832,
    'Ukrainian_i': 0x6a6,
    'braille_dots_1256': 0x1002833,
    'braille_dots_1257': 0x1002853,
    'uogonek': 0x3f9,
    'Ccircumflex': 0x2c6,
    'braille_dots_1258': 0x1002893,
    'Macedonia_dse': 0x6a5,
    'Omacron': 0x3d2,
    'Iogonek': 0x3c7,
    'J': 0x4a,
    'ISO_Release_Margin_Left': 0xfe29,
    'Arabic_percent': 0x100066a,
    'braille_dots_124678': 0x10028eb,
    'e': 0x65,
    'Greek_omegaaccent': 0x7bb,
    'braille_dots_1678': 0x10028e1,
    'braille_dots_123478': 0x10028cf,
    'dead_belowdot': 0xfe60,
    'doubleacute': 0x1bd,
    'ogonek': 0x1b2,
    'ae': 0xe6,
    'ohornacute': 0x1001edb,
    'Byelorussian_SHORTU': 0x6be,
    'Hangul_RieulTieut': 0xeae,
    'Arabic_hamza': 0x5c1,
    'at': 0x40,
    'Georgian_hoe': 0x10010f5,
    'braille_dots_2478': 0x10028ca,
    'hebrew_chet': 0xce7,
    'braille_dots_148': 0x1002889,
    '5': 0x35,
    'Thai_paiyannoi': 0xdcf,
    'Cyrillic_DE': 0x6e4,
    'Wcircumflex': 0x1000174,
    'abrevebelowdot': 0x1001eb7,
    'Ediaeresis': 0xcb,
    'Cyrillic_ve': 0x6d7,
    'includes': 0x8db,
    'horizconnector': 0x8a3,
    'Arabic_shadda': 0x5f1,
    'braille_dots_178': 0x10028c1,
    'Amacron': 0x3c0,
    'Georgian_don': 0x10010d3,
    'Hangul_U': 0xecc,
    'Terminate_Server': 0xfed5,
    'thorn': 0xfe,
    'Ukrainian_I': 0x6b6,
    'kana_middledot': 0x4a5,
    'Greek_OMICRONaccent': 0x7a7,
    'Hangul_A': 0xebf,
    'u': 0x75,
    'Hangul_E': 0xec4,
    'Hangul_I': 0xed3,
    'Cyrillic_che_descender': 0x10004b7,
    'Hangul_O': 0xec7,
    'aring': 0xe5,
    'uprightcorner': 0x9eb,
    'Cyrillic_SHORTI': 0x6ea,
    'Zen_Koho': 0xff3d,
    'dollar': 0x24,
    'Greek_omicronaccent': 0x7b7,
    'KP_9': 0xffb9,
    'braille_dots_12357': 0x1002857,
    'Ygrave': 0x1001ef2,
    'braille_dots_13467': 0x100286d,
    'braille_dots_13468': 0x10028ad,
    '3270_Setup': 0xfd17,
    'Thai_lu': 0xdc6,
    'twothirds': 0xab1,
    'ubelowdot': 0x1001ee5,
    'Armenian_shesht': 0x100055b,
    'kana_closingbracket': 0x4a3,
    'cuberoot': 0x100221b,
    'ISO_Group_Latch': 0xfe06,
    'Acircumflexacute': 0x1001ea4,
    'amacron': 0x3e0,
    'Armenian_ra': 0x100057c,
    'braille_dots_246': 0x100282a,
    'latincross': 0xad9,
    'Yacute': 0xdd,
    'Ocircumflexgrave': 0x1001ed2,
    'Greek_BETA': 0x7c2,
    'Georgian_tar': 0x10010e2,
    'Greek_ZETA': 0x7c6,
    'Otilde': 0xd5,
    'Georgian_tan': 0x10010d7,
    'ISO_First_Group_Lock': 0xfe0d,
    'section': 0xa7,
    'Thai_khokhon': 0xda5,
    'botleftsqbracket': 0x8a8,
    'Ecircumflexbelowdot': 0x1001ec6,
    'braille_dots_12358': 0x1002897,
    'braille_dots_12356': 0x1002837,
    'Thai_dochada': 0xdae,
    'K': 0x4b,
    'KP_Begin': 0xff9d,
    'dead_capital_schwa': 0xfe8b,
    'emspace': 0xaa1,
    'Thai_lekkao': 0xdf9,
    'Aring': 0xc5,
    'telephonerecorder': 0xafa,
    'Cyrillic_CHE': 0x6fe,
    'vertbar': 0x9f8,
    'LiraSign': 0x10020a4,
    'Thai_khorakhang': 0xda6,
    'Greek_LAMDA': 0x7cb,
    'enfilledcircbullet': 0xae6,
    'braille_dots_1467': 0x1002869,
    'Acircumflexbelowdot': 0x1001eac,
    'Hangul_SsangPieub': 0xeb3,
    'rcedilla': 0x3b3,
    'braille_dots_1468': 0x10028a9,
    'emptyset': 0x1002205,
    'Gbreve': 0x2ab,
    'Hangul_J_NieunJieuj': 0xed8,
    'Arabic_ddal': 0x1000688,
    'Arabic_heh_doachashmee': 0x10006be,
    'Hangul_MultipleCandidate': 0xff3d,
    '6': 0x36,
    'braille_dots_1345678': 0x10028fd,
    'dead_circumflex': 0xfe52,
    'EcuSign': 0x10020a0,
    'scaron': 0x1b9,
    'dead_E': 0xfe83,
    'diamond': 0xaed,
    'dead_A': 0xfe81,
    'dead_O': 0xfe87,
    'dead_I': 0xfe85,
    'dead_U': 0xfe89,
    'Linefeed': 0xff0a,
    'asciicircum': 0x5e,
    'Dcaron': 0x1cf,
    'Cyrillic_ka': 0x6cb,
    'Ecircumflexgrave': 0x1001ec0,
    'dead_e': 0xfe82,
    'dead_a': 0xfe80,
    'emopencircle': 0xace,
    'hebrew_finalnun': 0xcef,
    'dead_o': 0xfe86,
    'dead_i': 0xfe84,
    'braille_dots_1356': 0x1002835,
    'dead_u': 0xfe88,
    'paragraph': 0xb6,
    'v': 0x76,
    'kana_HE': 0x4cd,
    'Ecircumflextilde': 0x1001ec4,
    'Scroll_Lock': 0xff14,
    'partialderivative': 0x8ef,
    'Armenian_ghat': 0x1000572,
    'Serbian_NJE': 0x6ba,
    'emopenrectangle': 0xacf,
    'Cyrillic_U_macron': 0x10004ee,
    'Serbian_LJE': 0x6b9,
    'ISO_Fast_Cursor_Up': 0xfe2e,
    'braille_dots_123468': 0x10028af,
    'fourthroot': 0x100221c,
    'Thai_chochan': 0xda8,
    'braille_dots_168': 0x10028a1,
    'braille_dots_123467': 0x100286f,
    'lacute': 0x1e5,
    'Cyrillic_HARDSIGN': 0x6ff,
    'Thai_thothung': 0xdb6,
    'Arabic_sad': 0x5d5,
    'icircumflex': 0xee,
    'RepeatKeys_Enable': 0xfe72,
    'ff': 0x9e3,
    'lefttack': 0xbdc,
    'dead_macron': 0xfe54,
    'Greek_theta': 0x7e8,
    'a': 0x61,
    'braille_dots_2468': 0x10028aa,
    'Cyrillic_ya': 0x6d1,
    'Greek_iotaaccent': 0x7b4,
    'braille_dots_2467': 0x100286a,
    'braille_dots_45678': 0x10028f8,
    'Hangul_PostHanja': 0xff3b,
    'Cyrillic_yu': 0x6c0,
    'oacute': 0xf3,
    'Hankaku': 0xff29,
    'uring': 0x1f9,
    'Armenian_se': 0x100057d,
    'Cyrillic_SHA': 0x6fb,
    'Obelowdot': 0x1001ecc,
    'Armenian_khe': 0x100056d,
    'braille_dots_146': 0x1002829,
    'Ohorn': 0x10001a0,
    'braille_dots_145': 0x1002819,
    'braille_dots_35678': 0x10028f4,
    'Hangul_PanSios': 0xef2,
    'braille_dots_14578': 0x10028d9,
    'Cyrillic_ka_descender': 0x100049b,
    'Scedilla': 0x1aa,
    'Thai_maiek': 0xde8,
    'braille_dots_24567': 0x100287a,
    'Thai_nonen': 0xdb3,
    'Macedonia_kje': 0x6ac,
    '3270_PA1': 0xfd0a,
    '3270_PA2': 0xfd0b,
    '3270_PA3': 0xfd0c,
    'braille_dots_24568': 0x10028ba,
    'braille_dots_12346': 0x100282f,
    'braille_dots_12468': 0x10028ab,
    'L': 0x4c,
    'AudibleBell_Enable': 0xfe7a,
    'Uhornbelowdot': 0x1001ef0,
    'lbelowdot': 0x1001e37,
    'Cyrillic_ER': 0x6f2,
    'Cyrillic_ES': 0x6f3,
    'omacron': 0x3f2,
    'Mode_switch': 0xff7e,
    'Cyrillic_EF': 0x6e6,
    'Thai_sarauee': 0xdd7,
    'dead_grave': 0xfe50,
    'braille_dots_34': 0x100280c,
    'Cyrillic_EN': 0x6ee,
    'Cyrillic_EL': 0x6ec,
    'Cyrillic_EM': 0x6ed,
    'End': 0xff57,
    'braille_dots_6': 0x1002820,
    'ISO_Level5_Latch': 0xfe12,
    'Hangul_Phieuf': 0xebd,
    '3270_AltCursor': 0xfd10,
    'Armenian_zhe': 0x100056a,
    'botleftsummation': 0x8b2,
    'Abrevegrave': 0x1001eb0,
    '7': 0x37,
    'signifblank': 0xaac,
    'kana_WA': 0x4dc,
    'KP_End': 0xff9c,
    'Farsi_yeh': 0x10006cc,
    'kana_WO': 0x4a6,
    '3270_ChangeScreen': 0xfd19,
    'Cyrillic_che_vertstroke': 0x10004b9,
    'Delete': 0xffff,
    'dead_diaeresis': 0xfe57,
    'imacron': 0x3ef,
    'phonographcopyright': 0xafb,
    'Arabic_hah': 0x5cd,
    'Armenian_hi': 0x1000575,
    'upshoe': 0xbc3,
    'Arabic_meem': 0x5e5,
    'filledrighttribullet': 0xadd,
    'w': 0x77,
    'ISO_Last_Group_Lock': 0xfe0f,
    'EuroSign': 0x20ac,
    'notequal': 0x8bd,
    'braille_dots_12348': 0x100288f,
    'KP_Space': 0xff80,
    'braille_dots_12345': 0x100281f,
    'radical': 0x8d6,
    'braille_dots_12347': 0x100284f,
    'Super_L': 0xffeb,
    'ninesubscript': 0x1002089,
    'Itilde': 0x3a5,
    'Cyrillic_ha': 0x6c8,
    'blank': 0x9df,
    'ecircumflextilde': 0x1001ec5,
    'ISO_Last_Group': 0xfe0e,
    'Arabic_kasratan': 0x5ed,
    'upleftcorner': 0x9ec,
    'tslash': 0x3bc,
    'botrightparens': 0x8ae,
    'Wgrave': 0x1001e80,
    'Greek_chi': 0x7f7,
    'Arabic_kasra': 0x5f0,
    'braille_dots_1478': 0x10028c9,
    'careof': 0xab8,
    'Greek_ALPHAaccent': 0x7a1,
    'Aogonek': 0x1a1,
    'Thai_bobaimai': 0xdba,
    'b': 0x62,
    'braille_dots_12345678': 0x10028ff,
    'Arabic_kaf': 0x5e3,
    'Cancel': 0xff69,
    'Georgian_man': 0x10010db,
    'ohornhook': 0x1001edf,
    'Arabic_rreh': 0x1000691,
    'ISO_Level3_Lock': 0xfe05,
    'braille_dots_125678': 0x10028f3,
    'xabovedot': 0x1001e8b,
    'racute': 0x1e0,
    'vertconnector': 0x8a6,
    'Ocaron': 0x10001d1,
    'Armenian_o': 0x1000585,
    'hebrew_beth': 0xce1,
    'Hangul_Nieun': 0xea4,
    'Emacron': 0x3aa,
    'yacute': 0xfd,
    'Armenian_PE': 0x100054a,
    'Pointer_Button5': 0xfeed,
    'Pointer_Button4': 0xfeec,
    'braille_dots_2346': 0x100282e,
    'Pointer_Button1': 0xfee9,
    'Pointer_Button3': 0xfeeb,
    'Pointer_Button2': 0xfeea,
    'quotedbl': 0x22,
    'containsas': 0x100220b,
    'M': 0x4d,
    'Hebrew_switch': 0xff7e,
    'Greek_lamda': 0x7eb,
    'kana_yo': 0x4ae,
    'braille_dots_123458': 0x100289f,
    'onesuperior': 0xb9,
    'Cyrillic_TSE': 0x6e3,
    'braille_dots_123457': 0x100285f,
    'braille_dots_123456': 0x100283f,
    'righttack': 0xbfc,
    'Georgian_gan': 0x10010d2,
    '3270_FieldMark': 0xfd02,
    'kana_ya': 0x4ac,
    'kana_yu': 0x4ad,
    'Armenian_NU': 0x1000546,
    'adiaeresis': 0xe4,
    'Georgian_har': 0x10010f4,
    'Armenian_VYUN': 0x1000552,
    'ocircumflexhook': 0x1001ed5,
    'braille_dots_467': 0x1002868,
    'Georgian_hae': 0x10010f0,
    'Ntilde': 0xd1,
    'ISO_Next_Group': 0xfe08,
    'questiondown': 0xbf,
    'babovedot': 0x1001e03,
    'dead_abovereversedcomma': 0xfe65,
    'Icircumflex': 0xce,
    'braille_dots_1568': 0x10028b1,
    'kana_FU': 0x4cc,
    'Ubelowdot': 0x1001ee4,
    'Armenian_men': 0x1000574,
    'Gcaron': 0x10001e6,
    'Thai_popla': 0xdbb,
    'Cyrillic_BE': 0x6e2,
    '8': 0x38,
    'circle': 0xbcf,
    'Etilde': 0x1001ebc,
    'Greek_UPSILON': 0x7d5,
    'Thai_thothan': 0xdb0,
    'filledlefttribullet': 0xadc,
    'Cyrillic_te': 0x6d4,
    'kana_u': 0x4a9,
    'braille_dots_468': 0x10028a8,
    'kana_o': 0x4ab,
    'kana_i': 0x4a8,
    'kana_e': 0x4aa,
    'braille_dots_157': 0x1002851,
    'braille_dots_156': 0x1002831,
    'kana_a': 0x4a7,
    'Greek_tau': 0x7f4,
    'Help': 0xff6a,
    'Cyrillic_U_straight': 0x10004ae,
    'kana_U': 0x4b3,
    'kana_N': 0x4dd,
    'kana_O': 0x4b5,
    'braille_dots_14567': 0x1002879,
    'kana_I': 0x4b2,
    'Thai_leksam': 0xdf3,
    'kana_E': 0x4b4,
    'braille_dots_14568': 0x10028b9,
    'kana_A': 0x4b1,
    'notapproxeq': 0x1002247,
    'kana_TO': 0x4c4,
    'ordfeminine': 0xaa,
    'kana_TI': 0x4c1,
    'Georgian_fi': 0x10010f6,
    'ISO_Prev_Group_Lock': 0xfe0b,
    'kana_TE': 0x4c3,
    'ISO_Fast_Cursor_Left': 0xfe2c,
    'kana_TA': 0x4c0,
    'underbar': 0xbc6,
    'ehook': 0x1001ebb,
    'braille_dots_4568': 0x10028b8,
    'kana_TU': 0x4c2,
    '3270_Ident': 0xfd13,
    'Cyrillic_PE': 0x6f0,
    'braceleft': 0x7b,
    'threefifths': 0xab4,
    'braille_dots_57': 0x1002850,
    'Greek_NU': 0x7cd,
    'zerosuperior': 0x1002070,
    'Ukrainian_yi': 0x6a7,
    'Acircumflex': 0xc2,
    'Ohornbelowdot': 0x1001ee2,
    'Oslash': 0xd8,
    'gbreve': 0x2bb,
    'Hangul_J_Dikeud': 0xeda,
    'Korean_Won': 0xeff,
    'Cyrillic_i_macron': 0x10004e3,
    'braille_dots_1578': 0x10028d1,
    'braille_dots_3': 0x1002804,
    'Armenian_tche': 0x1000573,
    'c': 0x63,
    'prescription': 0xad4,
    'Pointer_Drag1': 0xfef5,
    'Pointer_Drag3': 0xfef7,
    'Pointer_Drag2': 0xfef6,
    'Pointer_Drag5': 0xfefd,
    'Pointer_Drag4': 0xfef8,
    'Ugrave': 0xd9,
    'Prev_Virtual_Screen': 0xfed1,
    'braille_dots_8': 0x1002880,
    'Thai_maitho': 0xde9,
    'bott': 0x9f6,
    'Serbian_tshe': 0x6ab,
    'Greek_finalsmallsigma': 0x7f3,
    'tintegral': 0x100222d,
    'Greek_pi': 0x7f0,
    'enfilledsqbullet': 0xae7,
    'hexagram': 0xada,
    'Thai_oang': 0xdcd,
    'Hangul_YU': 0xed0,
    'Hangul_Special': 0xff3f,
    'Armenian_cha': 0x1000579,
    'braille_dots_12578': 0x10028d3,
    'Hangul_switch': 0xff7e,
    'Kana_Lock': 0xff2d,
    'N': 0x4e,
    'ibelowdot': 0x1001ecb,
    'uhorngrave': 0x1001eeb,
    'braille_dots_12378': 0x10028c7,
    'Ohornhook': 0x1001ede,
    'ISO_Lock': 0xfe01,
    'Cyrillic_nje': 0x6aa,
    'ISO_Level3_Latch': 0xfe04,
    'braceright': 0x7d,
    'brokenbar': 0xa6,
    'ecircumflexbelowdot': 0x1001ec7,
    'Serbian_DZE': 0x6bf,
    'dead_tilde': 0xfe53,
    'rightarrow': 0x8fd,
    'Hangul_Kiyeog': 0xea1,
    'Arabic_heh_goal': 0x10006c1,
    'BackSpace': 0xff08,
    'Georgian_can': 0x10010ea,
    '9': 0x39,
    'ISO_Continuous_Underline': 0xfe30,
    'Insert': 0xff63,
    'gabovedot': 0x2f5,
    'hebrew_zayin': 0xce6,
    'Cyrillic_ie': 0x6c5,
    'Udiaeresis': 0xdc,
    'Cyrillic_io': 0x6a3,
    'Hangul_J_PanSios': 0xef8,
    'hebrew_yod': 0xce9,
    'y': 0x79,
    'Arabic_sukun': 0x5f2,
    'wdiaeresis': 0x1001e85,
    'ISO_First_Group': 0xfe0c,
    'ocircumflexgrave': 0x1001ed3,
    'KP_Down': 0xff99,
    'Ecircumflexhook': 0x1001ec2,
    'ISO_Release_Both_Margins': 0xfe2b,
    'Thai_loling': 0xdc5,
    'braille_dots_278': 0x10028c2,
    'braille_dots_1278': 0x10028c3,
    'KP_Decimal': 0xffae,
    'acute': 0xb4,
    'kana_TSU': 0x4c2,
    'braille_dots_23467': 0x100286e,
    'Acircumflexgrave': 0x1001ea6,
    '3270_Jump': 0xfd12,
    'd': 0x64,
    'Scircumflex': 0x2de,
    'ssharp': 0xdf,
    'OE': 0x13bc,
    'ocircumflexacute': 0x1001ed1,
    'Find': 0xff68,
    'braille_dots_67': 0x1002860,
    'twosubscript': 0x1002082,
    'braille_dots_68': 0x10028a0,
    'Arabic_seen': 0x5d3,
    'Thai_lakkhangyao': 0xde5,
    'Igrave': 0xcc,
    'jcircumflex': 0x2bc,
    'hebrew_ayin': 0xcf2,
    'Thai_moma': 0xdc1,
    'Cyrillic_dzhe': 0x6af,
    'Armenian_accent': 0x100055b,
    'Arabic_zain': 0x5d2,
    'braille_dots_1245678': 0x10028fb,
    'Lcedilla': 0x3a6,
    'ellipsis': 0xaae,
    'Georgian_we': 0x10010f3,
    'O': 0x4f,
    'Uhorn': 0x10001af,
    'botleftparens': 0x8ac,
    'abrevegrave': 0x1001eb1,
    'Thai_maihanakat_maitho': 0xdde,
    'caron': 0x1b7,
    'singlelowquotemark': 0xafd,
    'Abelowdot': 0x1001ea0,
    'fivesixths': 0xab7,
    'dead_stroke': 0xfe63,
    'threesuperior': 0xb3,
    'Arabic_qaf': 0x5e2,
    'sevensubscript': 0x1002087,
    'braille_dots_3578': 0x10028d4,
    'integral': 0x8bf,
    'Overlay2_Enable': 0xfe79,
    'fourfifths': 0xab5,
    'KP_Equal': 0xffbd,
    'Abrevebelowdot': 0x1001eb6,
    'braille_dots_4578': 0x10028d8,
    'question': 0x3f,
    'hebrew_bet': 0xce1,
    'Arabic_peh': 0x100067e,
    'Last_Virtual_Screen': 0xfed4,
    'hebrew_nun': 0xcf0,
    'rightshoe': 0xbd8,
    'ecircumflexhook': 0x1001ec3,
    'registered': 0xae,
    'Pointer_DfltBtnNext': 0xfefb,
    'Georgian_en': 0x10010d4,
    'Hangul_OE': 0xeca,
    'Armenian_YECH': 0x1000535,
    'Ohornacute': 0x1001eda,
    'Ograve': 0xd2,
    'Hangul_RieulHieuh': 0xeb0,
    'kana_SA': 0x4bb,
    'Pointer_Left': 0xfee0,
    'Arabic_waw': 0x5e8,
    'Armenian_VEV': 0x100054e,
    'braille_dots_456': 0x1002838,
    'z': 0x7a,
    'ISO_Release_Margin_Right': 0xfe2a,
    'braille_dots_12567': 0x1002873,
    'Armenian_amanak': 0x100055c,
    'braille_dots_12568': 0x10028b3,
    'Page_Up': 0xff55,
    'braille_dots_12367': 0x1002867,
    'KP_Subtract': 0xffad,
    'Arabic_lam': 0x5e4,
    'braille_dots_12368': 0x10028a7,
    'emfilledrect': 0xadf,
    'Macedonia_gje': 0x6a2,
    'Hangul_J_Tieut': 0xeec,
    'kcedilla': 0x3f3,
    'ninesuperior': 0x1002079,
    'Armenian_ayb': 0x1000561,
    'kana_ME': 0x4d2,
    'Greek_OMEGAaccent': 0x7ab,
    'AE': 0xc6,
    'leftpointer': 0xaea,
    'braille_dots_1456': 0x1002839,
    'braille_dots_1457': 0x1002859,
    'botintegral': 0x8a5,
    'aacute': 0xe1,
    'abrevehook': 0x1001eb3,
    'Armenian_full_stop': 0x1000589,
    'wcircumflex': 0x1000175,
    'implies': 0x8ce,
    'Thai_chochang': 0xdaa,
    'Greek_RHO': 0x7d1,
    'overline': 0x47e,
    'Babovedot': 0x1001e02,
    'acircumflexacute': 0x1001ea5,
    'Caps_Lock': 0xffe5,
    'PesetaSign': 0x10020a7,
    'Thai_leksong': 0xdf2,
    'Arabic_superscript_alef': 0x1000670,
    'rightcaret': 0xba6,
    'Greek_omega': 0x7f9,
    'dead_belowring': 0xfe67,
    'Greek_PHI': 0x7d6,
    'Armenian_RE': 0x1000550,
    'Armenian_RA': 0x100054c,
    'masculine': 0xba,
    'Cyrillic_de': 0x6c4,
    'rightmiddlecurlybrace': 0x8b0,
    'braille_dots_23458': 0x100289e,
    'Thai_totao': 0xdb5,
    'femalesymbol': 0xaf8,
    'P': 0x50,
    'underscore': 0x5f,
    'Cyrillic_ghe': 0x6c7,
    'Hangul_J_NieunHieuh': 0xed9,
    'KP_Multiply': 0xffaa,
    'F7': 0xffc4,
    'Ibreve': 0x100012c,
    'Uogonek': 0x3d9,
    'udiaeresis': 0xfc,
    'Select': 0xff60,
    'Thai_leksun': 0xdf0,
    'First_Virtual_Screen': 0xfed0,
    'Thai_phosamphao': 0xdc0,
    'F24': 0xffd5,
    'braille_dots_2348': 0x100288e,
    'Macedonia_KJE': 0x6bc,
    'braille_dots_2345': 0x100281e,
    'braille_dots_2347': 0x100284e,
    'Armenian_TCHE': 0x1000543,
    'Eabovedot': 0x3cc,
    'KP_Home': 0xff95,
    'diaeresis': 0xa8,
    'RupeeSign': 0x10020a8,
    'Armenian_da': 0x1000564,
    'prolongedsound': 0x4b0,
    'degree': 0xb0,
    'Georgian_phar': 0x10010e4,
    'Hyper_L': 0xffed,
    'kana_MU': 0x4d1,
    'Armenian_question': 0x100055e,
    'Prior': 0xff55,
    'Hangul_J_Hieuh': 0xeee,
    'copyright': 0xa9,
    'braille_dots_2567': 0x1002872,
    'Georgian_ghan': 0x10010e6,
    'Thai_wowaen': 0xdc7,
    'Ocircumflexbelowdot': 0x1001ed8,
    'Arabic_hamzaonwaw': 0x5c4,
    'KP_Prior': 0xff9a,
    'Greek_ETAaccent': 0x7a3,
    'dcaron': 0x1ef,
    'Ibelowdot': 0x1001eca,
    'Arabic_tatweel': 0x5e0,
    'braille_dots_3568': 0x10028b4,
    'braille_dots_3567': 0x1002874,
    'Hangul_YAE': 0xec2,
    'Armenian_vo': 0x1000578,
    'bracketleft': 0x5b,
    '3270_Record': 0xfd18,
    'filledtribulletup': 0xae8,
    'Ebelowdot': 0x1001eb8,
    'F1': 0xffbe,
    'F2': 0xffbf,
    'F3': 0xffc0,
    'F4': 0xffc1,
    'F5': 0xffc2,
    'F6': 0xffc3,
    'f': 0x66,
    'F8': 0xffc5,
    'F9': 0xffc6,
    'Ukrainian_ie': 0x6a4,
    'rightpointer': 0xaeb,
    'Eogonek': 0x1ca,
    'Hangul_Romaja': 0xff36,
    'Hangul_Pieub': 0xeb2,
    'Hangul_Hieuh': 0xebe,
    'overbar': 0xbc0,
    'Hangul_Rieul': 0xea9,
    'Hangul_SsangSios': 0xeb6,
    'hebrew_samech': 0xcf1,
    'trademarkincircle': 0xacb,
    'Serbian_DJE': 0x6b1,
    'eabovedot': 0x3ec,
    'Ahook': 0x1001ea2,
    'umacron': 0x3fe,
    'Byelorussian_shortu': 0x6ae,
    'Q': 0x51,
    'em3space': 0xaa3,
    'Armenian_INI': 0x100053b,
    'braille_dots_78': 0x10028c0,
    'Cyrillic_CHE_descender': 0x10004b6,
    'ahook': 0x1001ea3,
    'kra': 0x3a2,
    'Greek_IOTAaccent': 0x7a4,
    'Zstroke': 0x10001b5,
    'ecircumflexgrave': 0x1001ec1,
    'braille_dots_158': 0x1002891,
    'Thai_fofan': 0xdbf,
    'comma': 0x2c,
    'hebrew_waw': 0xce5,
    'X': 0x58,
    'Ybelowdot': 0x1001ef4,
    'Cyrillic_SHHA': 0x10004ba,
    'lf': 0x9e5,
    'ISO_Set_Margin_Left': 0xfe27,
    'Eisu_Shift': 0xff2f,
    'onesixth': 0xab6,
    'Hangul_Sios': 0xeb5,
    'Armenian_AT': 0x1000538,
    'Hangul_SingleCandidate': 0xff3c,
    'Execute': 0xff62,
    'Armenian_ZHE': 0x100053a,
    'greater': 0x3e,
    'uacute': 0xfa,
    'Ehook': 0x1001eba,
    'musicalsharp': 0xaf5,
    'Thai_thophuthao': 0xdb2,
    'Hangul_J_Rieul': 0xedb,
    'cedilla': 0xb8,
    'Hangul_SsangDikeud': 0xea8,
    'Armenian_PYUR': 0x1000553,
    'dead_breve': 0xfe55,
    'braille_dots_368': 0x10028a4,
    '3270_EraseInput': 0xfd07,
    'exclamdown': 0xa1,
    'Hangul_Cieuc': 0xeba,
    'Armenian_ligature_ew': 0x1000587,
    'braille_dots_134568': 0x10028bd,
    'endash': 0xaaa,
    'notidentical': 0x1002262,
    'Gcedilla': 0x3ab,
    'Thai_khokhuat': 0xda3,
    'braille_dots_134567': 0x100287d,
    'Next': 0xff56,
    'Iabovedot': 0x2a9,
    'agrave': 0xe0,
    'Thai_saraa': 0xdd0,
    'Print': 0xff61,
    'WonSign': 0x10020a9,
    'Ocircumflextilde': 0x1001ed6,
    'Cyrillic_u_straight_bar': 0x10004b1,
    'Georgian_par': 0x10010de,
    'braille_dots_24578': 0x10028da,
    'Ecaron': 0x1cc,
    'Lcaron': 0x1a5,
    'kana_switch': 0xff7e,
    'Cyrillic_ZHE': 0x6f6,
    'Greek_ETA': 0x7c7,
    'braille_dots_2358': 0x1002896,
    'Armenian_HI': 0x1000545,
    'x': 0x78,
    'braille_dots_2356': 0x1002836,
    'script_switch': 0xff7e,
    'ISO_Partial_Line_Up': 0xfe23,
    'openrectbullet': 0xae2,
    'Cyrillic_es': 0x6d3,
    'g': 0x67,
    'Arabic_question_mark': 0x5bf,
    'uhorn': 0x10001b0,
    'Cyrillic_ef': 0x6c6,
    'odoubleacute': 0x1f5,
    'signaturemark': 0xaca,
    'Cyrillic_el': 0x6cc,
    'Cyrillic_em': 0x6cd,
    'Pause': 0xff13,
    'Armenian_tyun': 0x100057f,
    'Armenian_HO': 0x1000540,
    'braille_dot_3': 0xfff3,
    'downcaret': 0xba8,
    'Hangul_NieunJieuj': 0xea5,
    'Meta_L': 0xffe7,
    'Georgian_char': 0x10010ed,
    'Thai_lochula': 0xdcc,
    'hebrew_pe': 0xcf4,
    'obelowdot': 0x1001ecd,
    'Meta_R': 0xffe8,
    'Ukranian_je': 0x6a4,
    'maltesecross': 0xaf0,
    'Georgian_un': 0x10010e3,
    'Arabic_yeh': 0x5ea,
    'Cyrillic_EN_descender': 0x10004a2,
    'braille_dots_2578': 0x10028d2,
    'Arabic_teh': 0x5ca,
    'Cyrillic_O_bar': 0x10004e8,
    'braille_dots_23578': 0x10028d6,
    'hebrew_finalpe': 0xcf3,
    'R': 0x52,
    'braille_dots_126': 0x1002823,
    'Sys_Req': 0xff15,
    '3270_Quit': 0xfd09,
    'dead_small_schwa': 0xfe8a,
    'braille_dots_48': 0x1002888,
    'braille_dots_46': 0x1002828,
    'stricteq': 0x1002263,
    'sixsuperior': 0x1002076,
    'Ccedilla': 0xc7,
    'Redo': 0xff66,
    'Greek_THETA': 0x7c8,
    'Cyrillic_U_straight_bar': 0x10004b0,
    'rightmiddlesummation': 0x8b7,
    'Armenian_DZA': 0x1000541,
    'Armenian_TSA': 0x100053e,
    'braille_dots_4567': 0x1002878,
    'NewSheqelSign': 0x10020aa,
    'kana_YO': 0x4d6,
    'braille_dots_13568': 0x10028b5,
    'itilde': 0x3b5,
    'kana_YU': 0x4d5,
    'kana_KU': 0x4b8,
    'braille_dots_478': 0x10028c8,
    'kana_KE': 0x4b9,
    'kana_KA': 0x4b6,
    'kana_KO': 0x4ba,
    'braille_dots_2568': 0x10028b2,
    'kana_KI': 0x4b7,
    'eightsubscript': 0x1002088,
    'Hangul_SsangKiyeog': 0xea2,
    'Arabic_heh': 0x5e7,
    '3270_Play': 0xfd16,
    'Arabic_dad': 0x5d6,
    'opentribulletup': 0xae3,
    'Dabovedot': 0x1001e0a,
    'Arabic_dal': 0x5cf,
    'Greek_LAMBDA': 0x7cb,
    'Arabic_tteh': 0x1000679,
    'Gcircumflex': 0x2d8,
    'braille_dots_1234678': 0x10028ef,
    'uptack': 0xbce,
    'ccedilla': 0xe7,
    'Greek_upsilon': 0x7f5,
    'Armenian_CHA': 0x1000549,
    'Georgian_xan': 0x10010ee,
    'Undo': 0xff65,
    'Thai_yoyak': 0xdc2,
    'Arabic_hamzaunderalef': 0x5c5,
    'Multi_key': 0xff20,
    'Zacute': 0x1ac,
    'topleftsummation': 0x8b1,
    'Arabic_tcheh': 0x1000686,
    'Cyrillic_tse': 0x6c3,
    'Ncaron': 0x1d2,
    'Arabic_theh': 0x5cb,
    'Serbian_nje': 0x6aa,
    'h': 0x68,
    'Armenian_gim': 0x1000563,
    'Hangul_WA': 0xec8,
    'Georgian_cil': 0x10010ec,
    'Serbian_lje': 0x6a9,
    '3270_CursorBlink': 0xfd0f,
    'Cyrillic_ZHE_descender': 0x1000496,
    'dead_iota': 0xfe5d,
    'Armenian_to': 0x1000569,
    'schwa': 0x1000259,
    'ooblique': 0xf8,
    'Arabic_gaf': 0x10006af,
    'braille_dots_235678': 0x10028f6,
    'oneeighth': 0xac3,
    'macron': 0xaf,
    'Cyrillic_be': 0x6c2,
    'Abreveacute': 0x1001eae,
    'sacute': 0x1b6,
    'braille_dots_234678': 0x10028ee,
    'jot': 0xbca,
    'Arabic_maddaonalef': 0x5c2,
    'braille_dots_134578': 0x10028dd,
    'botvertsummationconnector': 0x8b4,
    '3270_PrintScreen': 0xfd1d,
    'S': 0x53,
    'exclam': 0x21,
    'ISO_Left_Tab': 0xfe20,
    'nabla': 0x8c5,
    'equal': 0x3d,
    'ISO_Enter': 0xfe34,
    'kana_tsu': 0x4af,
    'malesymbol': 0xaf7,
    'eth': 0xf0,
    'Racute': 0x1c0,
    'Pointer_UpLeft': 0xfee4,
    'hyphen': 0xad,
    'Thai_hohip': 0xdcb,
    'ncedilla': 0x3f1,
    'zacute': 0x1bc,
    'MillSign': 0x10020a5,
    'braille_dots_2368': 0x10028a6,
    'dead_abovedot': 0xfe56,
    'cr': 0x9e4,
    'doublelowquotemark': 0xafe,
    'Greek_CHI': 0x7d7,
    'Armenian_ben': 0x1000562,
    'braille_dots_123568': 0x10028b7,
    'braille_dots_123567': 0x1002877,
    'trademark': 0xac9,
    'Aacute': 0xc1,
    'cent': 0xa2,
    'Armenian_fe': 0x1000586,
    'ohornbelowdot': 0x1001ee3,
    'Hangul_KkogjiDalrinIeung': 0xef3,
    'leftcaret': 0xba3,
    'Armenian_TO': 0x1000539,
    'Hangul_J_Ieung': 0xee8,
    'topleftsqbracket': 0x8a7,
    'KP_0': 0xffb0,
    'KP_1': 0xffb1,
    'KP_2': 0xffb2,
    'KP_3': 0xffb3,
    'KP_4': 0xffb4,
    'KP_5': 0xffb5,
    'KP_6': 0xffb6,
    'KP_7': 0xffb7,
    'KP_8': 0xffb8,
    'Cyrillic_zhe_descender': 0x1000497,
    'Cyrillic_pe': 0x6d0,
    'Ukranian_yi': 0x6a7,
    'Oacute': 0xd3,
    'KP_Left': 0xff96,
    'Greek_EPSILONaccent': 0x7a2,
    'threeeighths': 0xac4,
    'cursor': 0xaff,
    'hebrew_zade': 0xcf6,
    'Ukrainian_YI': 0x6b7,
    'hebrew_zadi': 0xcf6,
    'braille_dots_23567': 0x1002876,
    'kana_HU': 0x4cc,
    'Thai_fofa': 0xdbd,
    'Pointer_Down': 0xfee3,
    'braille_dots_23568': 0x10028b6,
    'ifonlyif': 0x8cd,
    'doubledagger': 0xaf2,
    'kana_HA': 0x4ca,
    'braille_dots_124': 0x100280b,
    'vt': 0x9e9,
    'kana_HI': 0x4cb,
    'odiaeresis': 0xf6,
    'kana_HO': 0x4ce,
    'Return': 0xff0d,
    'Cyrillic_u_straight': 0x10004af,
    'Georgian_zhar': 0x10010df,
    'Arabic_switch': 0xff7e,
    'braille_dots_38': 0x1002884,
    'Georgian_khar': 0x10010e5,
    'braille_dots_37': 0x1002844,
    'braille_dots_36': 0x1002824,
    'braille_dots_35': 0x1002814,
    'Arabic_ain': 0x5d9,
    'Pointer_Drag_Dflt': 0xfef4,
    'infinity': 0x8c2,
    'Greek_psi': 0x7f8,
    'Cyrillic_che': 0x6de,
    'botrightsqbracket': 0x8aa,
    'quad': 0xbcc,
    'dead_hook': 0xfe61,
    'KP_Right': 0xff98,
    'braille_dots_14678': 0x10028e9,
    'Armenian_ho': 0x1000570,
    'Armenian_vev': 0x100057e,
    'abreveacute': 0x1001eaf,
    'emdash': 0xaa9,
    'braille_dots_34578': 0x10028dc,
    'i': 0x69,
    'Greek_PI': 0x7d0,
    'braille_dots_13578': 0x10028d5,
    'Arabic_hamzaonyeh': 0x5c6,
    'Hangul_NieunHieuh': 0xea6,
    '3270_KeyClick': 0xfd11,
    'rightdoublequotemark': 0xad3,
    'acircumflexgrave': 0x1001ea7,
    'Thai_khokhai': 0xda2,
    'less': 0x3c,
    '3270_Attn': 0xfd0e,
    'Greek_epsilonaccent': 0x7b2,
    'Greek_epsilon': 0x7e5,
    'Armenian_yech': 0x1000565,
    'Arabic_fathatan': 0x5eb,
    'braille_dots_56': 0x1002830,
    'braille_dots_1': 0x1002801,
    'Thai_saraaimaimalai': 0xde4,
    'braille_dots_2': 0x1002802,
    'braille_dots_5': 0x1002810,
    'Zcaron': 0x1ae,
    'braille_dots_7': 0x1002840,
    'Georgian_he': 0x10010f1,
    'Greek_accentdieresis': 0x7ae,
    'Zenkaku_Hankaku': 0xff2a,
    'braille_dots_267': 0x1002862,
    'braille_dots_268': 0x10028a2,
    'Greek_TAU': 0x7d4,
    'identical': 0x8cf,
    'enspace': 0xaa2,
    'dead_belowtilde': 0xfe6a,
    'Tcedilla': 0x1de,
    'T': 0x54,
    'Macedonia_GJE': 0x6b2,
    'Hangul_J_RieulHieuh': 0xee2,
    'braille_dots_58': 0x1002890,
    'intersection': 0x8dc,
    'ecaron': 0x1ec,
    'Armenian_za': 0x1000566,
    'fivesubscript': 0x1002085,
    'Xabovedot': 0x1001e8a,
    'parenright': 0x29,
    'dead_voiced_sound': 0xfe5e,
    'because': 0x1002235,
    'eightsuperior': 0x1002078,
    'udoubleacute': 0x1fb,
    'toprightsummation': 0x8b5,
    'braille_dots_678': 0x10028e0,
    'Arabic_keheh': 0x10006a9,
    'Tslash': 0x3ac,
    'Armenian_TSO': 0x1000551,
    'R14': 0xffdf,
    'R15': 0xffe0,
    'R12': 0xffdd,
    'R13': 0xffde,
    'R10': 0xffdb,
    'R11': 0xffdc,
    'utilde': 0x3fd,
    'cabovedot': 0x2e5,
    'Thai_saraii': 0xdd5,
    'topleftparens': 0x8ab,
    'dead_belowbreve': 0xfe6b,
    'Kanji': 0xff21,
    'Up': 0xff52,
    'Hyper_R': 0xffee,
    '3270_DeleteWord': 0xfd1a,
    'Greek_UPSILONdieresis': 0x7a9,
    'filledtribulletdown': 0xae9,
    'Cyrillic_GHE': 0x6e7,
    'Thai_maichattawa': 0xdeb,
    'Obarred': 0x100019f,
    'Greek_iota': 0x7e9,
    'hebrew_kuf': 0xcf7,
    'Armenian_vyun': 0x1000582,
    'Thai_sarau': 0xdd8,
    'Thai_sarai': 0xdd4,
    'Thai_sarao': 0xde2,
    'decimalpoint': 0xabd,
    'Thai_sarae': 0xde0,
    'braille_dots_5678': 0x10028f0,
    'pabovedot': 0x1001e57,
    'braille_dots_25678': 0x10028f2,
    'Cyrillic_sha': 0x6db,
    'yhook': 0x1001ef7,
    'braille_dots_345': 0x100281c,
    'function': 0x8f6,
    'upcaret': 0xba9,
    'ISO_Group_Lock': 0xfe07,
    'ht': 0x9e2,
    'Ukranian_i': 0x6a6,
    'ISO_Center_Object': 0xfe33,
    'braille_dots_124578': 0x10028db,
    'Armenian_AYB': 0x1000531,
    'kana_conjunctive': 0x4a5,
    'Armenian_SE': 0x100054d,
    'Hangul_Jamo': 0xff35,
    'iogonek': 0x3e7,
    'j': 0x6a,
    'Ukranian_I': 0x6b6,
    'braille_dots_123578': 0x10028d7,
    'minutes': 0xad6,
    'Thai_choching': 0xda9,
    'ycircumflex': 0x1000177,
    'Cyrillic_LJE': 0x6b9,
    'Thai_khokhwai': 0xda4,
    'Arabic_ghain': 0x5da,
    'hebrew_resh': 0xcf8,
    'braille_dots_2378': 0x10028c6,
    'Hangul_WI': 0xecf,
    'percent': 0x25,
    'Cyrillic_o_bar': 0x10004e9,
    'ibreve': 0x100012d,
    'Armenian_apostrophe': 0x100055a,
    'Georgian_nar': 0x10010dc,
    'ubreve': 0x2fd,
    'bracketright': 0x5d,
    'ISO_Prev_Group': 0xfe0a,
    'Armenian_TYUN': 0x100054f,
    'Imacron': 0x3cf,
    'ecircumflexacute': 0x1001ebf,
    'scedilla': 0x1ba,
    'variation': 0x8c1,
    'U': 0x55,
    'Georgian_rae': 0x10010e0,
    'dead_horn': 0xfe62,
    'Hangul_J_Cieuc': 0xeea,
    'Nacute': 0x1d1,
    'ISO_Move_Line_Down': 0xfe22,
    'digitspace': 0xaa5,
    'braille_dots_28': 0x1002882,
    'braille_dots_23': 0x1002806,
    'braille_dots_24': 0x100280a,
    'braille_dots_25': 0x1002812,
    'braille_dots_26': 0x1002822,
    'ytilde': 0x1001ef9,
}
names = {
    0x20: 'space',
    0x21: 'exclam',
    0x22: 'quotedbl',
    0x23: 'numbersign',
    0x24: 'dollar',
    0x25: 'percent',
    0x26: 'ampersand',
    0x27: 'apostrophe',
    0x28: 'parenleft',
    0x29: 'parenright',
    0x2a: 'asterisk',
    0x2b: 'plus',
    0x2c: 'comma',
    0x2d: 'minus',
    0x2e: 'period',
    0x2f: 'slash',
    0x30: '0',
    0x31: '1',
    0x32: '2',
    0x33: '3',
    0x34: '4',
    0x35: '5',
    0x36: '6',
    0x37: '7',
    0x38: '8',
    0x39: '9',
    0x3a: 'colon',
    0x3b: 'semicolon',
    0x3c: 'less',
    0x3d: 'equal',
    0x3e: 'greater',
    0x3f: 'question',
    0x40: 'at',
    0x41: 'A',
    0x42: 'B',
    0x43: 'C',
    0x44: 'D',
    0x45: 'E',
    0x46: 'F',
    0x47: 'G',
    0x48: 'H',
    0x49: 'I',
    0x4a: 'J',
    0x4b: 'K',
    0x4c: 'L',
    0x4d: 'M',
    0x4e: 'N',
    0x4f: 'O',
    0x50: 'P',
    0x51: 'Q',
    0x52: 'R',
    0x53: 'S',
    0x54: 'T',
    0x55: 'U',
    0x56: 'V',
    0x57: 'W',
    0x58: 'X',
    0x59: 'Y',
    0x5a: 'Z',
    0x5b: 'bracketleft',
    0x5c: 'backslash',
    0x5d: 'bracketright',
    0x5e: 'asciicircum',
    0x5f: 'underscore',
    0x60: 'quoteleft',
    0x61: 'a',
    0x62: 'b',
    0x63: 'c',
    0x64: 'd',
    0x65: 'e',
    0x66: 'f',
    0x67: 'g',
    0x68: 'h',
    0x69: 'i',
    0x6a: 'j',
    0x6b: 'k',
    0x6c: 'l',
    0x6d: 'm',
    0x6e: 'n',
    0x6f: 'o',
    0x70: 'p',
    0x71: 'q',
    0x72: 'r',
    0x73: 's',
    0x1002074: 'foursuperior',
    0x1002075: 'fivesuperior',
    0x76: 'v',
    0x1002077: 'sevensuperior',
    0x78: 'x',
    0x79: 'y',
    0x7a: 'z',
    0x7b: 'braceleft',
    0x7c: 'bar',
    0x7d: 'braceright',
    0x7e: 'asciitilde',
    0x1002080: 'zerosubscript',
    0x1002081: 'onesubscript',
    0x1002082: 'twosubscript',
    0x1002083: 'threesubscript',
    0x1002084: 'foursubscript',
    0x1002085: 'fivesubscript',
    0x1002086: 'sixsubscript',
    0x1002087: 'sevensubscript',
    0x1002088: 'eightsubscript',
    0x1002089: 'ninesubscript',
    0xa0: 'nobreakspace',
    0x10020a1: 'ColonSign',
    0x10020a2: 'CruzeiroSign',
    0xa3: 'sterling',
    0xa4: 'currency',
    0xa5: 'yen',
    0x10020a6: 'NairaSign',
    0xa7: 'section',
    0xa8: 'diaeresis',
    0xa9: 'copyright',
    0xaa: 'ordfeminine',
    0x10020ab: 'DongSign',
    0xac: 'notsign',
    0xad: 'hyphen',
    0xae: 'registered',
    0xaf: 'macron',
    0xb0: 'degree',
    0xb1: 'plusminus',
    0xb2: 'twosuperior',
    0xb3: 'threesuperior',
    0xb4: 'acute',
    0xb5: 'mu',
    0xb6: 'paragraph',
    0xb7: 'periodcentered',
    0xb8: 'cedilla',
    0xb9: 'onesuperior',
    0xba: 'masculine',
    0xbb: 'guillemotright',
    0xbc: 'onequarter',
    0xbd: 'onehalf',
    0xbe: 'threequarters',
    0xbf: 'questiondown',
    0xc0: 'Agrave',
    0xc1: 'Aacute',
    0xc2: 'Acircumflex',
    0xc3: 'Atilde',
    0xc4: 'Adiaeresis',
    0xc5: 'Aring',
    0xc6: 'AE',
    0xc7: 'Ccedilla',
    0xc8: 'Egrave',
    0xc9: 'Eacute',
    0xca: 'Ecircumflex',
    0xcb: 'Ediaeresis',
    0xcc: 'Igrave',
    0xcd: 'Iacute',
    0xce: 'Icircumflex',
    0xcf: 'Idiaeresis',
    0xd0: 'Eth',
    0xd1: 'Ntilde',
    0xd2: 'Ograve',
    0xd3: 'Oacute',
    0xd4: 'Ocircumflex',
    0xd5: 'Otilde',
    0xd6: 'Odiaeresis',
    0xd7: 'multiply',
    0xd8: 'Oslash',
    0xd9: 'Ugrave',
    0xda: 'Uacute',
    0xdb: 'Ucircumflex',
    0xdc: 'Udiaeresis',
    0xdd: 'Yacute',
    0xde: 'Thorn',
    0xdf: 'ssharp',
    0xe0: 'agrave',
    0xe1: 'aacute',
    0xe2: 'acircumflex',
    0xe3: 'atilde',
    0xe4: 'adiaeresis',
    0xe5: 'aring',
    0xe6: 'ae',
    0xe7: 'ccedilla',
    0xe8: 'egrave',
    0xe9: 'eacute',
    0xea: 'ecircumflex',
    0xeb: 'ediaeresis',
    0xec: 'igrave',
    0xed: 'iacute',
    0xee: 'icircumflex',
    0xef: 'idiaeresis',
    0xf0: 'eth',
    0xf1: 'ntilde',
    0xf2: 'ograve',
    0xf3: 'oacute',
    0xf4: 'ocircumflex',
    0xf5: 'otilde',
    0xf6: 'odiaeresis',
    0xf7: 'division',
    0xf8: 'ooblique',
    0xf9: 'ugrave',
    0xfa: 'uacute',
    0xfb: 'ucircumflex',
    0xfc: 'udiaeresis',
    0xfd: 'yacute',
    0xfe: 'thorn',
    0xff: 'ydiaeresis',
    0x100012c: 'Ibreve',
    0x100012d: 'ibreve',
    0x1000174: 'Wcircumflex',
    0x1000175: 'wcircumflex',
    0x1000176: 'Ycircumflex',
    0x1000177: 'ycircumflex',
    0x100018f: 'SCHWA',
    0x100019f: 'Obarred',
    0x10001a0: 'Ohorn',
    0x10001a1: 'ohorn',
    0x1a2: 'breve',
    0x1a3: 'Lstroke',
    0x1a5: 'Lcaron',
    0x1a6: 'Sacute',
    0x1a9: 'Scaron',
    0x1aa: 'Scedilla',
    0x1ab: 'Tcaron',
    0x1ac: 'Zacute',
    0x1ae: 'Zcaron',
    0x1af: 'Zabovedot',
    0x10001b0: 'uhorn',
    0x1b1: 'aogonek',
    0x1b2: 'ogonek',
    0x1b3: 'lstroke',
    0x1b5: 'lcaron',
    0x10001b6: 'zstroke',
    0x1b7: 'caron',
    0x1b9: 'scaron',
    0x1ba: 'scedilla',
    0x1bb: 'tcaron',
    0x1bc: 'zacute',
    0x1bd: 'doubleacute',
    0x1be: 'zcaron',
    0x1bf: 'zabovedot',
    0x1c0: 'Racute',
    0x1c3: 'Abreve',
    0x1c5: 'Lacute',
    0x1c6: 'Cacute',
    0x1c8: 'Ccaron',
    0x1ca: 'Eogonek',
    0x1cc: 'Ecaron',
    0x1cf: 'Dcaron',
    0x1d0: 'Dstroke',
    0x10001d1: 'Ocaron',
    0x10001d2: 'ocaron',
    0x1d5: 'Odoubleacute',
    0x1d8: 'Rcaron',
    0x1d9: 'Uring',
    0x1db: 'Udoubleacute',
    0x1de: 'Tcedilla',
    0x1e0: 'racute',
    0x1e3: 'abreve',
    0x1e5: 'lacute',
    0x10001e6: 'Gcaron',
    0x10001e7: 'gcaron',
    0x1e8: 'ccaron',
    0x1ea: 'eogonek',
    0x1ec: 'ecaron',
    0x1ef: 'dcaron',
    0x1f0: 'dstroke',
    0x1f1: 'nacute',
    0x1f2: 'ncaron',
    0x1f5: 'odoubleacute',
    0x1f8: 'rcaron',
    0x1f9: 'uring',
    0x1fb: 'udoubleacute',
    0x1fe: 'tcedilla',
    0x1ff: 'abovedot',
    0x1002202: 'partdifferential',
    0x1002205: 'emptyset',
    0x1002208: 'elementof',
    0x1002209: 'notelementof',
    0x100220b: 'containsas',
    0x100221a: 'squareroot',
    0x100221b: 'cuberoot',
    0x100221c: 'fourthroot',
    0x100222c: 'dintegral',
    0x100222d: 'tintegral',
    0x1002235: 'because',
    0x1002247: 'notapproxeq',
    0x1002248: 'approxeq',
    0x1000259: 'schwa',
    0x1002262: 'notidentical',
    0x1002263: 'stricteq',
    0x1000275: 'obarred',
    0x2a1: 'Hstroke',
    0x2a6: 'Hcircumflex',
    0x2a9: 'Iabovedot',
    0x2ab: 'Gbreve',
    0x2ac: 'Jcircumflex',
    0x2b1: 'hstroke',
    0x2b6: 'hcircumflex',
    0x2b9: 'idotless',
    0x2bb: 'gbreve',
    0x2bc: 'jcircumflex',
    0x75: 'u',
    0x2c5: 'Cabovedot',
    0x2c6: 'Ccircumflex',
    0x77: 'w',
    0x1002078: 'eightsuperior',
    0x2d5: 'Gabovedot',
    0x1002079: 'ninesuperior',
    0x2d8: 'Gcircumflex',
    0x2dd: 'Ubreve',
    0x2de: 'Scircumflex',
    0x2e5: 'cabovedot',
    0x2e6: 'ccircumflex',
    0x2f5: 'gabovedot',
    0x2f8: 'gcircumflex',
    0x2fd: 'ubreve',
    0x2fe: 'scircumflex',
    0x3a2: 'kra',
    0x3a3: 'Rcedilla',
    0x3a5: 'Itilde',
    0x3a6: 'Lcedilla',
    0x3aa: 'Emacron',
    0x3ab: 'Gcedilla',
    0x3ac: 'Tslash',
    0x3b3: 'rcedilla',
    0x3b5: 'itilde',
    0x3b6: 'lcedilla',
    0x3ba: 'emacron',
    0x3bb: 'gcedilla',
    0x3bc: 'tslash',
    0x3bd: 'ENG',
    0x3bf: 'eng',
    0x3c0: 'Amacron',
    0x10020a0: 'EcuSign',
    0x3c7: 'Iogonek',
    0x3cc: 'Eabovedot',
    0xa2: 'cent',
    0x3cf: 'Imacron',
    0x3d1: 'Ncedilla',
    0x3d2: 'Omacron',
    0x3d3: 'Kcedilla',
    0x10020a4: 'LiraSign',
    0x3dd: 'Utilde',
    0x3de: 'Umacron',
    0x10020a5: 'MillSign',
    0x3e0: 'amacron',
    0xa6: 'brokenbar',
    0x3e7: 'iogonek',
    0x10020a7: 'PesetaSign',
    0x3ec: 'eabovedot',
    0x3ef: 'imacron',
    0x10020a8: 'RupeeSign',
    0x3f2: 'omacron',
    0x3f3: 'kcedilla',
    0x10020a9: 'WonSign',
    0x3f9: 'uogonek',
    0x10020aa: 'NewSheqelSign',
    0x3fe: 'umacron',
    0xab: 'guillemotleft',
    0x20ac: 'EuroSign',
    0x47e: 'overline',
    0x1000492: 'Cyrillic_GHE_bar',
    0x1000493: 'Cyrillic_ghe_bar',
    0x1000496: 'Cyrillic_ZHE_descender',
    0x1000497: 'Cyrillic_zhe_descender',
    0x100049a: 'Cyrillic_KA_descender',
    0x100049b: 'Cyrillic_ka_descender',
    0x100049c: 'Cyrillic_KA_vertstroke',
    0x100049d: 'Cyrillic_ka_vertstroke',
    0x4a1: 'kana_fullstop',
    0x4a2: 'kana_openingbracket',
    0x4a3: 'kana_closingbracket',
    0x4a4: 'kana_comma',
    0x4a5: 'kana_conjunctive',
    0x4a6: 'kana_WO',
    0x4a7: 'kana_a',
    0x4a8: 'kana_i',
    0x4a9: 'kana_u',
    0x4aa: 'kana_e',
    0x4ab: 'kana_o',
    0x4ac: 'kana_ya',
    0x4ad: 'kana_yu',
    0x10004ae: 'Cyrillic_U_straight',
    0x4af: 'kana_tsu',
    0x4b0: 'prolongedsound',
    0x4b1: 'kana_A',
    0x4b2: 'kana_I',
    0x4b3: 'kana_U',
    0x4b4: 'kana_E',
    0x4b5: 'kana_O',
    0x10004b6: 'Cyrillic_CHE_descender',
    0x10004b7: 'Cyrillic_che_descender',
    0x10004b8: 'Cyrillic_CHE_vertstroke',
    0x10004b9: 'Cyrillic_che_vertstroke',
    0x10004ba: 'Cyrillic_SHHA',
    0x10004bb: 'Cyrillic_shha',
    0x4bc: 'kana_SHI',
    0x4bd: 'kana_SU',
    0x4be: 'kana_SE',
    0x4bf: 'kana_SO',
    0x4c0: 'kana_TA',
    0x4c1: 'kana_TI',
    0x4c2: 'kana_TSU',
    0x4c3: 'kana_TE',
    0x4c4: 'kana_TO',
    0x4c5: 'kana_NA',
    0x4c6: 'kana_NI',
    0x4c7: 'kana_NU',
    0x4c8: 'kana_NE',
    0x4c9: 'kana_NO',
    0x4ca: 'kana_HA',
    0x4cb: 'kana_HI',
    0x4cc: 'kana_HU',
    0x4cd: 'kana_HE',
    0x4ce: 'kana_HO',
    0x4cf: 'kana_MA',
    0x4d0: 'kana_MI',
    0x4d1: 'kana_MU',
    0x4d2: 'kana_ME',
    0x4d3: 'kana_MO',
    0x4d4: 'kana_YA',
    0x4d5: 'kana_YU',
    0x4d6: 'kana_YO',
    0x4d7: 'kana_RA',
    0x10004d8: 'Cyrillic_SCHWA',
    0x4d9: 'kana_RU',
    0x4da: 'kana_RE',
    0x4db: 'kana_RO',
    0x4dc: 'kana_WA',
    0x4dd: 'kana_N',
    0x4de: 'voicedsound',
    0x4df: 'semivoicedsound',
    0x10004e2: 'Cyrillic_I_macron',
    0x10004e3: 'Cyrillic_i_macron',
    0x10004e8: 'Cyrillic_O_bar',
    0x10004e9: 'Cyrillic_o_bar',
    0x10004ee: 'Cyrillic_U_macron',
    0x10004ef: 'Cyrillic_u_macron',
    0x1000531: 'Armenian_AYB',
    0x1000532: 'Armenian_BEN',
    0x1000533: 'Armenian_GIM',
    0x1000534: 'Armenian_DA',
    0x1000535: 'Armenian_YECH',
    0x1000536: 'Armenian_ZA',
    0x1000537: 'Armenian_E',
    0x1000538: 'Armenian_AT',
    0x1000539: 'Armenian_TO',
    0x100053a: 'Armenian_ZHE',
    0x100053b: 'Armenian_INI',
    0x100053c: 'Armenian_LYUN',
    0x100053d: 'Armenian_KHE',
    0x100053e: 'Armenian_TSA',
    0x100053f: 'Armenian_KEN',
    0x1000540: 'Armenian_HO',
    0x1000541: 'Armenian_DZA',
    0x1000542: 'Armenian_GHAT',
    0x1000543: 'Armenian_TCHE',
    0x1000544: 'Armenian_MEN',
    0x1000545: 'Armenian_HI',
    0x1000546: 'Armenian_NU',
    0x1000547: 'Armenian_SHA',
    0x1000548: 'Armenian_VO',
    0x1000549: 'Armenian_CHA',
    0x100054a: 'Armenian_PE',
    0x100054b: 'Armenian_JE',
    0x100054c: 'Armenian_RA',
    0x100054d: 'Armenian_SE',
    0x100054e: 'Armenian_VEV',
    0x100054f: 'Armenian_TYUN',
    0x1000550: 'Armenian_RE',
    0x1000551: 'Armenian_TSO',
    0x1000552: 'Armenian_VYUN',
    0x1000553: 'Armenian_PYUR',
    0x1000554: 'Armenian_KE',
    0x1000555: 'Armenian_O',
    0x1000556: 'Armenian_FE',
    0x100055a: 'Armenian_apostrophe',
    0x100055b: 'Armenian_accent',
    0x100055c: 'Armenian_amanak',
    0x100055d: 'Armenian_separation_mark',
    0x100055e: 'Armenian_question',
    0x1000561: 'Armenian_ayb',
    0x1000562: 'Armenian_ben',
    0x1000563: 'Armenian_gim',
    0x1000564: 'Armenian_da',
    0x1000565: 'Armenian_yech',
    0x1000566: 'Armenian_za',
    0x1000567: 'Armenian_e',
    0x1000568: 'Armenian_at',
    0x1000569: 'Armenian_to',
    0x100056a: 'Armenian_zhe',
    0x100056b: 'Armenian_ini',
    0x100056c: 'Armenian_lyun',
    0x100056d: 'Armenian_khe',
    0x100056e: 'Armenian_tsa',
    0x100056f: 'Armenian_ken',
    0x1000570: 'Armenian_ho',
    0x1000571: 'Armenian_dza',
    0x1000572: 'Armenian_ghat',
    0x1000573: 'Armenian_tche',
    0x1000574: 'Armenian_men',
    0x1000575: 'Armenian_hi',
    0x1000576: 'Armenian_nu',
    0x1000577: 'Armenian_sha',
    0x1000578: 'Armenian_vo',
    0x1000579: 'Armenian_cha',
    0x100057a: 'Armenian_pe',
    0x100057b: 'Armenian_je',
    0x100057c: 'Armenian_ra',
    0x100057d: 'Armenian_se',
    0x100057e: 'Armenian_vev',
    0x100057f: 'Armenian_tyun',
    0x1000580: 'Armenian_re',
    0x1000581: 'Armenian_tso',
    0x1000582: 'Armenian_vyun',
    0x1000583: 'Armenian_pyur',
    0x1000584: 'Armenian_ke',
    0x1000585: 'Armenian_o',
    0x1000586: 'Armenian_fe',
    0x1000587: 'Armenian_ligature_ew',
    0x1000589: 'Armenian_full_stop',
    0x100058a: 'Armenian_yentamna',
    0x5ac: 'Arabic_comma',
    0x5bb: 'Arabic_semicolon',
    0x5bf: 'Arabic_question_mark',
    0x5c1: 'Arabic_hamza',
    0x5c2: 'Arabic_maddaonalef',
    0x5c3: 'Arabic_hamzaonalef',
    0x5c4: 'Arabic_hamzaonwaw',
    0x5c5: 'Arabic_hamzaunderalef',
    0x5c6: 'Arabic_hamzaonyeh',
    0x5c7: 'Arabic_alef',
    0x5c8: 'Arabic_beh',
    0x5c9: 'Arabic_tehmarbuta',
    0x5ca: 'Arabic_teh',
    0x5cb: 'Arabic_theh',
    0x5cc: 'Arabic_jeem',
    0x5cd: 'Arabic_hah',
    0x5ce: 'Arabic_khah',
    0x5cf: 'Arabic_dal',
    0x5d0: 'Arabic_thal',
    0x5d1: 'Arabic_ra',
    0x5d2: 'Arabic_zain',
    0x5d3: 'Arabic_seen',
    0x5d4: 'Arabic_sheen',
    0x5d5: 'Arabic_sad',
    0x5d6: 'Arabic_dad',
    0x5d7: 'Arabic_tah',
    0x5d8: 'Arabic_zah',
    0x5d9: 'Arabic_ain',
    0x5da: 'Arabic_ghain',
    0x5e0: 'Arabic_tatweel',
    0x5e1: 'Arabic_feh',
    0x5e2: 'Arabic_qaf',
    0x5e3: 'Arabic_kaf',
    0x5e4: 'Arabic_lam',
    0x5e5: 'Arabic_meem',
    0x5e6: 'Arabic_noon',
    0x5e7: 'Arabic_heh',
    0x5e8: 'Arabic_waw',
    0x5e9: 'Arabic_alefmaksura',
    0x5ea: 'Arabic_yeh',
    0x5eb: 'Arabic_fathatan',
    0x5ec: 'Arabic_dammatan',
    0x5ed: 'Arabic_kasratan',
    0x5ee: 'Arabic_fatha',
    0x5ef: 'Arabic_damma',
    0x5f0: 'Arabic_kasra',
    0x5f1: 'Arabic_shadda',
    0x5f2: 'Arabic_sukun',
    0x1000653: 'Arabic_madda_above',
    0x1000654: 'Arabic_hamza_above',
    0x1000655: 'Arabic_hamza_below',
    0x1000660: 'Arabic_0',
    0x1000661: 'Arabic_1',
    0x1000662: 'Arabic_2',
    0x1000663: 'Arabic_3',
    0x1000664: 'Arabic_4',
    0x1000665: 'Arabic_5',
    0x1000666: 'Arabic_6',
    0x1000667: 'Arabic_7',
    0x1000668: 'Arabic_8',
    0x1000669: 'Arabic_9',
    0x100066a: 'Arabic_percent',
    0x1000670: 'Arabic_superscript_alef',
    0x1000679: 'Arabic_tteh',
    0x100067e: 'Arabic_peh',
    0x1000686: 'Arabic_tcheh',
    0x1000688: 'Arabic_ddal',
    0x1000691: 'Arabic_rreh',
    0x1000698: 'Arabic_jeh',
    0x6a1: 'Serbian_dje',
    0x6a2: 'Macedonia_gje',
    0x6a3: 'Cyrillic_io',
    0x10006a4: 'Arabic_veh',
    0x6a5: 'Macedonia_dse',
    0x6a6: 'Ukranian_i',
    0x6a7: 'Ukranian_yi',
    0x6a8: 'Cyrillic_je',
    0x6a9: 'Serbian_lje',
    0x6aa: 'Serbian_nje',
    0x6ab: 'Serbian_tshe',
    0x6ac: 'Macedonia_kje',
    0x6ad: 'Ukrainian_ghe_with_upturn',
    0x6ae: 'Byelorussian_shortu',
    0x6af: 'Cyrillic_dzhe',
    0x6b0: 'numerosign',
    0x6b1: 'Serbian_DJE',
    0x6b2: 'Macedonia_GJE',
    0x6b3: 'Cyrillic_IO',
    0x6b4: 'Ukranian_JE',
    0x6b5: 'Macedonia_DSE',
    0x6b6: 'Ukranian_I',
    0x6b7: 'Ukrainian_YI',
    0x6b8: 'Serbian_JE',
    0x6b9: 'Cyrillic_LJE',
    0x6ba: 'Serbian_NJE',
    0x6bb: 'Serbian_TSHE',
    0x6bc: 'Macedonia_KJE',
    0x6bd: 'Ukrainian_GHE_WITH_UPTURN',
    0x6be: 'Byelorussian_SHORTU',
    0x6bf: 'Serbian_DZE',
    0x6c0: 'Cyrillic_yu',
    0x10006c1: 'Arabic_heh_goal',
    0x6c2: 'Cyrillic_be',
    0x6c3: 'Cyrillic_tse',
    0x6c4: 'Cyrillic_de',
    0x6c5: 'Cyrillic_ie',
    0x6c6: 'Cyrillic_ef',
    0x6c7: 'Cyrillic_ghe',
    0x6c8: 'Cyrillic_ha',
    0x6c9: 'Cyrillic_i',
    0x6ca: 'Cyrillic_shorti',
    0x6cb: 'Cyrillic_ka',
    0x10006cc: 'Farsi_yeh',
    0x6cd: 'Cyrillic_em',
    0x6ce: 'Cyrillic_en',
    0x6cf: 'Cyrillic_o',
    0x6d0: 'Cyrillic_pe',
    0x6d1: 'Cyrillic_ya',
    0x10006d2: 'Arabic_yeh_baree',
    0x6d3: 'Cyrillic_es',
    0x10006d4: 'Arabic_fullstop',
    0x6d5: 'Cyrillic_u',
    0x6d6: 'Cyrillic_zhe',
    0x6d7: 'Cyrillic_ve',
    0x6d8: 'Cyrillic_softsign',
    0x6d9: 'Cyrillic_yeru',
    0x6da: 'Cyrillic_ze',
    0x6db: 'Cyrillic_sha',
    0x6dc: 'Cyrillic_e',
    0x6dd: 'Cyrillic_shcha',
    0x6de: 'Cyrillic_che',
    0x6df: 'Cyrillic_hardsign',
    0x6e0: 'Cyrillic_YU',
    0x6e1: 'Cyrillic_A',
    0x6e2: 'Cyrillic_BE',
    0x6e3: 'Cyrillic_TSE',
    0x6e4: 'Cyrillic_DE',
    0x6e5: 'Cyrillic_IE',
    0x6e6: 'Cyrillic_EF',
    0x6e7: 'Cyrillic_GHE',
    0x6e8: 'Cyrillic_HA',
    0x6e9: 'Cyrillic_I',
    0x6ea: 'Cyrillic_SHORTI',
    0x6eb: 'Cyrillic_KA',
    0x6ec: 'Cyrillic_EL',
    0x6ed: 'Cyrillic_EM',
    0x6ee: 'Cyrillic_EN',
    0x6ef: 'Cyrillic_O',
    0x6f0: 'Cyrillic_PE',
    0x6f1: 'Cyrillic_YA',
    0x10006f2: 'Farsi_2',
    0x6f3: 'Cyrillic_ES',
    0x10006f4: 'Farsi_4',
    0x6f5: 'Cyrillic_U',
    0x10006f6: 'Farsi_6',
    0x6f7: 'Cyrillic_VE',
    0x10006f8: 'Farsi_8',
    0x6f9: 'Cyrillic_YERU',
    0x6fa: 'Cyrillic_ZE',
    0x6fb: 'Cyrillic_SHA',
    0x6fc: 'Cyrillic_E',
    0x6fd: 'Cyrillic_SHCHA',
    0x6fe: 'Cyrillic_CHE',
    0x6ff: 'Cyrillic_HARDSIGN',
    0x6a4: 'Ukranian_je',
    0x7a1: 'Greek_ALPHAaccent',
    0x7a2: 'Greek_EPSILONaccent',
    0x7a3: 'Greek_ETAaccent',
    0x7a4: 'Greek_IOTAaccent',
    0x7a5: 'Greek_IOTAdiaeresis',
    0x7a7: 'Greek_OMICRONaccent',
    0x7a8: 'Greek_UPSILONaccent',
    0x7a9: 'Greek_UPSILONdieresis',
    0x7ab: 'Greek_OMEGAaccent',
    0x7ae: 'Greek_accentdieresis',
    0x7af: 'Greek_horizbar',
    0x7b1: 'Greek_alphaaccent',
    0x7b2: 'Greek_epsilonaccent',
    0x7b3: 'Greek_etaaccent',
    0x7b4: 'Greek_iotaaccent',
    0x7b5: 'Greek_iotadieresis',
    0x7b6: 'Greek_iotaaccentdieresis',
    0x7b7: 'Greek_omicronaccent',
    0x7b8: 'Greek_upsilonaccent',
    0x7b9: 'Greek_upsilondieresis',
    0x7ba: 'Greek_upsilonaccentdieresis',
    0x7bb: 'Greek_omegaaccent',
    0x7c1: 'Greek_ALPHA',
    0x7c2: 'Greek_BETA',
    0x7c3: 'Greek_GAMMA',
    0x7c4: 'Greek_DELTA',
    0x7c5: 'Greek_EPSILON',
    0x7c6: 'Greek_ZETA',
    0x7c7: 'Greek_ETA',
    0x7c8: 'Greek_THETA',
    0x7c9: 'Greek_IOTA',
    0x7ca: 'Greek_KAPPA',
    0x7cb: 'Greek_LAMBDA',
    0x7cc: 'Greek_MU',
    0x7cd: 'Greek_NU',
    0x7ce: 'Greek_XI',
    0x7cf: 'Greek_OMICRON',
    0x7d0: 'Greek_PI',
    0x7d1: 'Greek_RHO',
    0x7d2: 'Greek_SIGMA',
    0x7d4: 'Greek_TAU',
    0x7d5: 'Greek_UPSILON',
    0x7d6: 'Greek_PHI',
    0x7d7: 'Greek_CHI',
    0x7d8: 'Greek_PSI',
    0x7d9: 'Greek_OMEGA',
    0x7e1: 'Greek_alpha',
    0x7e2: 'Greek_beta',
    0x7e3: 'Greek_gamma',
    0x7e4: 'Greek_delta',
    0x7e5: 'Greek_epsilon',
    0x7e6: 'Greek_zeta',
    0x7e7: 'Greek_eta',
    0x7e8: 'Greek_theta',
    0x7e9: 'Greek_iota',
    0x7ea: 'Greek_kappa',
    0x7eb: 'Greek_lamda',
    0x7ec: 'Greek_mu',
    0x7ed: 'Greek_nu',
    0x7ee: 'Greek_xi',
    0x7ef: 'Greek_omicron',
    0x7f0: 'Greek_pi',
    0x7f1: 'Greek_rho',
    0x7f2: 'Greek_sigma',
    0x7f3: 'Greek_finalsmallsigma',
    0x7f4: 'Greek_tau',
    0x7f5: 'Greek_upsilon',
    0x7f6: 'Greek_phi',
    0x7f7: 'Greek_chi',
    0x7f8: 'Greek_psi',
    0x7f9: 'Greek_omega',
    0x1002800: 'braille_blank',
    0x1002801: 'braille_dots_1',
    0x1002802: 'braille_dots_2',
    0x1002803: 'braille_dots_12',
    0x1002804: 'braille_dots_3',
    0x1002805: 'braille_dots_13',
    0x1002806: 'braille_dots_23',
    0x1002807: 'braille_dots_123',
    0x1002808: 'braille_dots_4',
    0x1002809: 'braille_dots_14',
    0x100280a: 'braille_dots_24',
    0x100280b: 'braille_dots_124',
    0x100280c: 'braille_dots_34',
    0x100280d: 'braille_dots_134',
    0x100280e: 'braille_dots_234',
    0x100280f: 'braille_dots_1234',
    0x1002810: 'braille_dots_5',
    0x1002811: 'braille_dots_15',
    0x1002812: 'braille_dots_25',
    0x1002813: 'braille_dots_125',
    0x1002814: 'braille_dots_35',
    0x1002815: 'braille_dots_135',
    0x1002816: 'braille_dots_235',
    0x1002817: 'braille_dots_1235',
    0x1002818: 'braille_dots_45',
    0x1002819: 'braille_dots_145',
    0x100281a: 'braille_dots_245',
    0x100281b: 'braille_dots_1245',
    0x100281c: 'braille_dots_345',
    0x100281d: 'braille_dots_1345',
    0x100281e: 'braille_dots_2345',
    0x100281f: 'braille_dots_12345',
    0x1002820: 'braille_dots_6',
    0x1002821: 'braille_dots_16',
    0x1002822: 'braille_dots_26',
    0x1002823: 'braille_dots_126',
    0x1002824: 'braille_dots_36',
    0x1002825: 'braille_dots_136',
    0x1002826: 'braille_dots_236',
    0x1002827: 'braille_dots_1236',
    0x1002828: 'braille_dots_46',
    0x1002829: 'braille_dots_146',
    0x100282a: 'braille_dots_246',
    0x100282b: 'braille_dots_1246',
    0x100282c: 'braille_dots_346',
    0x100282d: 'braille_dots_1346',
    0x100282e: 'braille_dots_2346',
    0x100282f: 'braille_dots_12346',
    0x1002830: 'braille_dots_56',
    0x1002831: 'braille_dots_156',
    0x1002832: 'braille_dots_256',
    0x1002833: 'braille_dots_1256',
    0x1002834: 'braille_dots_356',
    0x1002835: 'braille_dots_1356',
    0x1002836: 'braille_dots_2356',
    0x1002837: 'braille_dots_12356',
    0x1002838: 'braille_dots_456',
    0x1002839: 'braille_dots_1456',
    0x100283a: 'braille_dots_2456',
    0x100283b: 'braille_dots_12456',
    0x100283c: 'braille_dots_3456',
    0x100283d: 'braille_dots_13456',
    0x100283e: 'braille_dots_23456',
    0x100283f: 'braille_dots_123456',
    0x1002840: 'braille_dots_7',
    0x1002841: 'braille_dots_17',
    0x1002842: 'braille_dots_27',
    0x1002843: 'braille_dots_127',
    0x1002844: 'braille_dots_37',
    0x1002845: 'braille_dots_137',
    0x1002846: 'braille_dots_237',
    0x1002847: 'braille_dots_1237',
    0x1002848: 'braille_dots_47',
    0x1002849: 'braille_dots_147',
    0x100284a: 'braille_dots_247',
    0x100284b: 'braille_dots_1247',
    0x100284c: 'braille_dots_347',
    0x100284d: 'braille_dots_1347',
    0x100284e: 'braille_dots_2347',
    0x100284f: 'braille_dots_12347',
    0x1002850: 'braille_dots_57',
    0x1002851: 'braille_dots_157',
    0x1002852: 'braille_dots_257',
    0x1002853: 'braille_dots_1257',
    0x1002854: 'braille_dots_357',
    0x1002855: 'braille_dots_1357',
    0x1002856: 'braille_dots_2357',
    0x1002857: 'braille_dots_12357',
    0x1002858: 'braille_dots_457',
    0x1002859: 'braille_dots_1457',
    0x100285a: 'braille_dots_2457',
    0x100285b: 'braille_dots_12457',
    0x100285c: 'braille_dots_3457',
    0x100285d: 'braille_dots_13457',
    0x100285e: 'braille_dots_23457',
    0x100285f: 'braille_dots_123457',
    0x1002860: 'braille_dots_67',
    0x1002861: 'braille_dots_167',
    0x1002862: 'braille_dots_267',
    0x1002863: 'braille_dots_1267',
    0x1002864: 'braille_dots_367',
    0x1002865: 'braille_dots_1367',
    0x1002866: 'braille_dots_2367',
    0x1002867: 'braille_dots_12367',
    0x1002868: 'braille_dots_467',
    0x1002869: 'braille_dots_1467',
    0x100286a: 'braille_dots_2467',
    0x100286b: 'braille_dots_12467',
    0x100286c: 'braille_dots_3467',
    0x100286d: 'braille_dots_13467',
    0x100286e: 'braille_dots_23467',
    0x100286f: 'braille_dots_123467',
    0x1002870: 'braille_dots_567',
    0x1002871: 'braille_dots_1567',
    0x1002872: 'braille_dots_2567',
    0x1002873: 'braille_dots_12567',
    0x1002874: 'braille_dots_3567',
    0x1002875: 'braille_dots_13567',
    0x1002876: 'braille_dots_23567',
    0x1002877: 'braille_dots_123567',
    0x1002878: 'braille_dots_4567',
    0x1002879: 'braille_dots_14567',
    0x100287a: 'braille_dots_24567',
    0x100287b: 'braille_dots_124567',
    0x100287c: 'braille_dots_34567',
    0x100287d: 'braille_dots_134567',
    0x100287e: 'braille_dots_234567',
    0x100287f: 'braille_dots_1234567',
    0x1002880: 'braille_dots_8',
    0x1002881: 'braille_dots_18',
    0x1002882: 'braille_dots_28',
    0x1002883: 'braille_dots_128',
    0x1002884: 'braille_dots_38',
    0x1002885: 'braille_dots_138',
    0x1002886: 'braille_dots_238',
    0x1002887: 'braille_dots_1238',
    0x1002888: 'braille_dots_48',
    0x1002889: 'braille_dots_148',
    0x100288a: 'braille_dots_248',
    0x100288b: 'braille_dots_1248',
    0x100288c: 'braille_dots_348',
    0x100288d: 'braille_dots_1348',
    0x100288e: 'braille_dots_2348',
    0x100288f: 'braille_dots_12348',
    0x1002890: 'braille_dots_58',
    0x1002891: 'braille_dots_158',
    0x1002892: 'braille_dots_258',
    0x1002893: 'braille_dots_1258',
    0x1002894: 'braille_dots_358',
    0x1002895: 'braille_dots_1358',
    0x1002896: 'braille_dots_2358',
    0x1002897: 'braille_dots_12358',
    0x1002898: 'braille_dots_458',
    0x1002899: 'braille_dots_1458',
    0x100289a: 'braille_dots_2458',
    0x100289b: 'braille_dots_12458',
    0x100289c: 'braille_dots_3458',
    0x100289d: 'braille_dots_13458',
    0x100289e: 'braille_dots_23458',
    0x100289f: 'braille_dots_123458',
    0x10028a0: 'braille_dots_68',
    0x8a1: 'leftradical',
    0x8a2: 'topleftradical',
    0x10028a3: 'braille_dots_1268',
    0x8a4: 'topintegral',
    0x10028a5: 'braille_dots_1368',
    0x8a6: 'vertconnector',
    0x10028a7: 'braille_dots_12368',
    0x8a8: 'botleftsqbracket',
    0x8a9: 'toprightsqbracket',
    0x10028aa: 'braille_dots_2468',
    0x10028ab: 'braille_dots_12468',
    0x10028ac: 'braille_dots_3468',
    0x8ad: 'toprightparens',
    0x10028ae: 'braille_dots_23468',
    0x8af: 'leftmiddlecurlybrace',
    0x10028b0: 'braille_dots_568',
    0x10028b1: 'braille_dots_1568',
    0x8b2: 'botleftsummation',
    0x8b3: 'topvertsummationconnector',
    0x10028b4: 'braille_dots_3568',
    0x10028b5: 'braille_dots_13568',
    0x8b6: 'botrightsummation',
    0x8b7: 'rightmiddlesummation',
    0x10028b8: 'braille_dots_4568',
    0x10028b9: 'braille_dots_14568',
    0x10028ba: 'braille_dots_24568',
    0x10028bb: 'braille_dots_124568',
    0x8bc: 'lessthanequal',
    0x8bd: 'notequal',
    0x8be: 'greaterthanequal',
    0x10028bf: 'braille_dots_1234568',
    0x8c0: 'therefore',
    0x10028c1: 'braille_dots_178',
    0x10028c2: 'braille_dots_278',
    0x10028c3: 'braille_dots_1278',
    0x10028c4: 'braille_dots_378',
    0x10028c5: 'braille_dots_1378',
    0x10028c6: 'braille_dots_2378',
    0x10028c7: 'braille_dots_12378',
    0x8c8: 'approximate',
    0x10028c9: 'braille_dots_1478',
    0x10028ca: 'braille_dots_2478',
    0x10028cb: 'braille_dots_12478',
    0x10028cc: 'braille_dots_3478',
    0x10028cd: 'braille_dots_13478',
    0x10028ce: 'braille_dots_23478',
    0x10028cf: 'braille_dots_123478',
    0x10028d0: 'braille_dots_578',
    0x10028d1: 'braille_dots_1578',
    0x10028d2: 'braille_dots_2578',
    0x10028d3: 'braille_dots_12578',
    0x10028d4: 'braille_dots_3578',
    0x10028d5: 'braille_dots_13578',
    0x8d6: 'radical',
    0x10028d7: 'braille_dots_123578',
    0x10028d8: 'braille_dots_4578',
    0x10028d9: 'braille_dots_14578',
    0x8da: 'includedin',
    0x8db: 'includes',
    0x10028dc: 'braille_dots_34578',
    0x8dd: 'union',
    0x10028de: 'braille_dots_234578',
    0x8df: 'logicalor',
    0x10028e0: 'braille_dots_678',
    0x10028e1: 'braille_dots_1678',
    0x10028e2: 'braille_dots_2678',
    0x10028e3: 'braille_dots_12678',
    0x10028e4: 'braille_dots_3678',
    0x10028e5: 'braille_dots_13678',
    0x10028e6: 'braille_dots_23678',
    0x10028e7: 'braille_dots_123678',
    0x10028e8: 'braille_dots_4678',
    0x10028e9: 'braille_dots_14678',
    0x10028ea: 'braille_dots_24678',
    0x10028eb: 'braille_dots_124678',
    0x10028ec: 'braille_dots_34678',
    0x10028ed: 'braille_dots_134678',
    0x10028ee: 'braille_dots_234678',
    0x8ef: 'partialderivative',
    0x10028f0: 'braille_dots_5678',
    0x10028f1: 'braille_dots_15678',
    0x10028f2: 'braille_dots_25678',
    0x10028f3: 'braille_dots_125678',
    0x10028f4: 'braille_dots_35678',
    0x10028f5: 'braille_dots_135678',
    0x10028f6: 'braille_dots_235678',
    0x10028f7: 'braille_dots_1235678',
    0x10028f8: 'braille_dots_45678',
    0x10028f9: 'braille_dots_145678',
    0x10028fa: 'braille_dots_245678',
    0x8fb: 'leftarrow',
    0x8fc: 'uparrow',
    0x10028fd: 'braille_dots_1345678',
    0x10028fe: 'braille_dots_2345678',
    0x10028ff: 'braille_dots_12345678',
    0x10006f0: 'Farsi_0',
    0x10006f1: 'Farsi_1',
    0x6f2: 'Cyrillic_ER',
    0x10006f3: 'Farsi_3',
    0x6f4: 'Cyrillic_TE',
    0x10006f5: 'Farsi_5',
    0x6f6: 'Cyrillic_ZHE',
    0x1a1: 'Aogonek',
    0x10006f7: 'Farsi_7',
    0x6f8: 'Cyrillic_SOFTSIGN',
    0x10006f9: 'Farsi_9',
    0x9df: 'blank',
    0x9e0: 'soliddiamond',
    0x9e1: 'checkerboard',
    0x9e2: 'ht',
    0x9e3: 'ff',
    0x9e4: 'cr',
    0x9e5: 'lf',
    0x9e8: 'nl',
    0x9e9: 'vt',
    0x9ea: 'lowrightcorner',
    0x9eb: 'uprightcorner',
    0x9ec: 'upleftcorner',
    0x9ed: 'lowleftcorner',
    0x9ee: 'crossinglines',
    0x9ef: 'horizlinescan1',
    0x9f0: 'horizlinescan3',
    0x9f1: 'horizlinescan5',
    0x9f2: 'horizlinescan7',
    0x9f3: 'horizlinescan9',
    0x9f4: 'leftt',
    0x9f5: 'rightt',
    0x9f6: 'bott',
    0x9f7: 'topt',
    0x9f8: 'vertbar',
    0x10006ba: 'Arabic_noon_ghunna',
    0x10001af: 'Uhorn',
    0x10001b5: 'Zstroke',
    0x1b6: 'sacute',
    0x1002076: 'sixsuperior',
    0x10006be: 'Arabic_heh_doachashmee',
    0xaa1: 'emspace',
    0xaa2: 'enspace',
    0xaa3: 'em3space',
    0xaa4: 'em4space',
    0xaa5: 'digitspace',
    0xaa6: 'punctspace',
    0xaa7: 'thinspace',
    0xaa8: 'hairspace',
    0xaa9: 'emdash',
    0xaaa: 'endash',
    0xaac: 'signifblank',
    0xaae: 'ellipsis',
    0xaaf: 'doubbaselinedot',
    0xab0: 'onethird',
    0xab1: 'twothirds',
    0xab2: 'onefifth',
    0xab3: 'twofifths',
    0xab4: 'threefifths',
    0xab5: 'fourfifths',
    0xab6: 'onesixth',
    0xab7: 'fivesixths',
    0xab8: 'careof',
    0xabb: 'figdash',
    0xabc: 'leftanglebracket',
    0xabd: 'decimalpoint',
    0xabe: 'rightanglebracket',
    0xabf: 'marker',
    0xac3: 'oneeighth',
    0xac4: 'threeeighths',
    0xac5: 'fiveeighths',
    0xac6: 'seveneighths',
    0xac9: 'trademark',
    0xaca: 'signaturemark',
    0xacb: 'trademarkincircle',
    0xacc: 'leftopentriangle',
    0xacd: 'rightopentriangle',
    0xace: 'emopencircle',
    0xacf: 'emopenrectangle',
    0xad0: 'leftsinglequotemark',
    0xad1: 'rightsinglequotemark',
    0xad2: 'leftdoublequotemark',
    0xad3: 'rightdoublequotemark',
    0xad4: 'prescription',
    0xad6: 'minutes',
    0xad7: 'seconds',
    0xad9: 'latincross',
    0xada: 'hexagram',
    0xadb: 'filledrectbullet',
    0xadc: 'filledlefttribullet',
    0xadd: 'filledrighttribullet',
    0xade: 'emfilledcircle',
    0xadf: 'emfilledrect',
    0xae0: 'enopencircbullet',
    0xae1: 'enopensquarebullet',
    0xae2: 'openrectbullet',
    0xae3: 'opentribulletup',
    0xae4: 'opentribulletdown',
    0xae5: 'openstar',
    0xae6: 'enfilledcircbullet',
    0xae7: 'enfilledsqbullet',
    0xae8: 'filledtribulletup',
    0xae9: 'filledtribulletdown',
    0xaea: 'leftpointer',
    0xaeb: 'rightpointer',
    0xaec: 'club',
    0xaed: 'diamond',
    0xaee: 'heart',
    0xaf0: 'maltesecross',
    0xaf1: 'dagger',
    0xaf2: 'doubledagger',
    0xaf3: 'checkmark',
    0xaf4: 'ballotcross',
    0xaf5: 'musicalsharp',
    0xaf6: 'musicalflat',
    0xaf7: 'malesymbol',
    0xaf8: 'femalesymbol',
    0xaf9: 'telephone',
    0xafa: 'telephonerecorder',
    0xafb: 'phonographcopyright',
    0xafc: 'caret',
    0xafd: 'singlelowquotemark',
    0xafe: 'doublelowquotemark',
    0xaff: 'cursor',
    0x1e6: 'cacute',
    0xba3: 'leftcaret',
    0xba6: 'rightcaret',
    0xba8: 'downcaret',
    0xba9: 'upcaret',
    0x10006af: 'Arabic_gaf',
    0xbc0: 'overbar',
    0xbc2: 'downtack',
    0xbc3: 'upshoe',
    0xbc4: 'downstile',
    0xbc6: 'underbar',
    0xbca: 'jot',
    0xbcc: 'quad',
    0xbce: 'uptack',
    0xbcf: 'circle',
    0xbd3: 'upstile',
    0xbd6: 'downshoe',
    0xbd8: 'rightshoe',
    0xbda: 'leftshoe',
    0xbdc: 'lefttack',
    0xbfc: 'righttack',
    0x6cc: 'Cyrillic_el',
    0x6d2: 'Cyrillic_er',
    0xcdf: 'hebrew_doublelowline',
    0xce0: 'hebrew_aleph',
    0xce1: 'hebrew_bet',
    0xce2: 'hebrew_gimel',
    0xce3: 'hebrew_daleth',
    0xce4: 'hebrew_he',
    0xce5: 'hebrew_waw',
    0xce6: 'hebrew_zayin',
    0xce7: 'hebrew_chet',
    0xce8: 'hebrew_tet',
    0xce9: 'hebrew_yod',
    0xcea: 'hebrew_finalkaph',
    0xceb: 'hebrew_kaph',
    0xcec: 'hebrew_lamed',
    0xced: 'hebrew_finalmem',
    0xcee: 'hebrew_mem',
    0xcef: 'hebrew_finalnun',
    0xcf0: 'hebrew_nun',
    0xcf1: 'hebrew_samech',
    0xcf2: 'hebrew_ayin',
    0xcf3: 'hebrew_finalpe',
    0xcf4: 'hebrew_pe',
    0xcf5: 'hebrew_finalzadi',
    0xcf6: 'hebrew_zadi',
    0xcf7: 'hebrew_kuf',
    0xcf8: 'hebrew_resh',
    0xcf9: 'hebrew_shin',
    0xcfa: 'hebrew_taf',
    0x6d4: 'Cyrillic_te',
    0x74: 't',
    0xda2: 'Thai_khokhai',
    0xda3: 'Thai_khokhuat',
    0xda4: 'Thai_khokhwai',
    0xda5: 'Thai_khokhon',
    0xda6: 'Thai_khorakhang',
    0xda7: 'Thai_ngongu',
    0xda8: 'Thai_chochan',
    0xda9: 'Thai_choching',
    0xdaa: 'Thai_chochang',
    0xdab: 'Thai_soso',
    0xdac: 'Thai_chochoe',
    0xdad: 'Thai_yoying',
    0xdae: 'Thai_dochada',
    0xdaf: 'Thai_topatak',
    0xdb0: 'Thai_thothan',
    0xdb1: 'Thai_thonangmontho',
    0xdb2: 'Thai_thophuthao',
    0xdb3: 'Thai_nonen',
    0xdb4: 'Thai_dodek',
    0xdb5: 'Thai_totao',
    0xdb6: 'Thai_thothung',
    0xdb7: 'Thai_thothahan',
    0xdb8: 'Thai_thothong',
    0xdb9: 'Thai_nonu',
    0xdba: 'Thai_bobaimai',
    0xdbb: 'Thai_popla',
    0xdbc: 'Thai_phophung',
    0xdbd: 'Thai_fofa',
    0xdbe: 'Thai_phophan',
    0xdbf: 'Thai_fofan',
    0xdc0: 'Thai_phosamphao',
    0xdc1: 'Thai_moma',
    0xdc2: 'Thai_yoyak',
    0xdc3: 'Thai_rorua',
    0xdc4: 'Thai_ru',
    0xdc5: 'Thai_loling',
    0xdc6: 'Thai_lu',
    0xdc7: 'Thai_wowaen',
    0xdc8: 'Thai_sosala',
    0xdc9: 'Thai_sorusi',
    0xdca: 'Thai_sosua',
    0xdcb: 'Thai_hohip',
    0xdcc: 'Thai_lochula',
    0xdcd: 'Thai_oang',
    0xdce: 'Thai_honokhuk',
    0xdcf: 'Thai_paiyannoi',
    0xdd0: 'Thai_saraa',
    0xdd1: 'Thai_maihanakat',
    0xdd2: 'Thai_saraaa',
    0xdd3: 'Thai_saraam',
    0xdd4: 'Thai_sarai',
    0xdd5: 'Thai_saraii',
    0xdd6: 'Thai_saraue',
    0xdd7: 'Thai_sarauee',
    0xdd8: 'Thai_sarau',
    0xdd9: 'Thai_sarauu',
    0xdda: 'Thai_phinthu',
    0xdde: 'Thai_maihanakat_maitho',
    0xddf: 'Thai_baht',
    0xde0: 'Thai_sarae',
    0xde1: 'Thai_saraae',
    0xde2: 'Thai_sarao',
    0xde3: 'Thai_saraaimaimuan',
    0xde4: 'Thai_saraaimaimalai',
    0xde5: 'Thai_lakkhangyao',
    0xde6: 'Thai_maiyamok',
    0xde7: 'Thai_maitaikhu',
    0xde8: 'Thai_maiek',
    0xde9: 'Thai_maitho',
    0xdea: 'Thai_maitri',
    0xdeb: 'Thai_maichattawa',
    0xdec: 'Thai_thanthakhat',
    0xded: 'Thai_nikhahit',
    0xdf0: 'Thai_leksun',
    0xdf1: 'Thai_leknung',
    0xdf2: 'Thai_leksong',
    0xdf3: 'Thai_leksam',
    0xdf4: 'Thai_leksi',
    0xdf5: 'Thai_lekha',
    0xdf6: 'Thai_lekhok',
    0xdf7: 'Thai_lekchet',
    0xdf8: 'Thai_lekpaet',
    0xdf9: 'Thai_lekkao',
    0x1002070: 'zerosuperior',
    0xfd11: '3270_KeyClick',
    0xfd17: '3270_Setup',
    0xea1: 'Hangul_Kiyeog',
    0xea2: 'Hangul_SsangKiyeog',
    0xea3: 'Hangul_KiyeogSios',
    0xea4: 'Hangul_Nieun',
    0xea5: 'Hangul_NieunJieuj',
    0xea6: 'Hangul_NieunHieuh',
    0xea7: 'Hangul_Dikeud',
    0xea8: 'Hangul_SsangDikeud',
    0xea9: 'Hangul_Rieul',
    0xeaa: 'Hangul_RieulKiyeog',
    0xeab: 'Hangul_RieulMieum',
    0xeac: 'Hangul_RieulPieub',
    0xead: 'Hangul_RieulSios',
    0xeae: 'Hangul_RieulTieut',
    0xeaf: 'Hangul_RieulPhieuf',
    0xeb0: 'Hangul_RieulHieuh',
    0xeb1: 'Hangul_Mieum',
    0xeb2: 'Hangul_Pieub',
    0xeb3: 'Hangul_SsangPieub',
    0xeb4: 'Hangul_PieubSios',
    0xeb5: 'Hangul_Sios',
    0xeb6: 'Hangul_SsangSios',
    0xeb7: 'Hangul_Ieung',
    0xeb8: 'Hangul_Jieuj',
    0xeb9: 'Hangul_SsangJieuj',
    0xeba: 'Hangul_Cieuc',
    0xebb: 'Hangul_Khieuq',
    0xebc: 'Hangul_Tieut',
    0xebd: 'Hangul_Phieuf',
    0xebe: 'Hangul_Hieuh',
    0xebf: 'Hangul_A',
    0xec0: 'Hangul_AE',
    0xec1: 'Hangul_YA',
    0xec2: 'Hangul_YAE',
    0xec3: 'Hangul_EO',
    0xec4: 'Hangul_E',
    0xec5: 'Hangul_YEO',
    0xec6: 'Hangul_YE',
    0xec7: 'Hangul_O',
    0xec8: 'Hangul_WA',
    0xec9: 'Hangul_WAE',
    0xeca: 'Hangul_OE',
    0xecb: 'Hangul_YO',
    0xecc: 'Hangul_U',
    0xecd: 'Hangul_WEO',
    0xece: 'Hangul_WE',
    0xecf: 'Hangul_WI',
    0xed0: 'Hangul_YU',
    0xed1: 'Hangul_EU',
    0xed2: 'Hangul_YI',
    0xed3: 'Hangul_I',
    0xed4: 'Hangul_J_Kiyeog',
    0xed5: 'Hangul_J_SsangKiyeog',
    0xed6: 'Hangul_J_KiyeogSios',
    0xed7: 'Hangul_J_Nieun',
    0xed8: 'Hangul_J_NieunJieuj',
    0xed9: 'Hangul_J_NieunHieuh',
    0xeda: 'Hangul_J_Dikeud',
    0xedb: 'Hangul_J_Rieul',
    0xedc: 'Hangul_J_RieulKiyeog',
    0xedd: 'Hangul_J_RieulMieum',
    0xede: 'Hangul_J_RieulPieub',
    0xedf: 'Hangul_J_RieulSios',
    0xee0: 'Hangul_J_RieulTieut',
    0xee1: 'Hangul_J_RieulPhieuf',
    0xee2: 'Hangul_J_RieulHieuh',
    0xee3: 'Hangul_J_Mieum',
    0xee4: 'Hangul_J_Pieub',
    0xee5: 'Hangul_J_PieubSios',
    0xee6: 'Hangul_J_Sios',
    0xee7: 'Hangul_J_SsangSios',
    0xee8: 'Hangul_J_Ieung',
    0xee9: 'Hangul_J_Jieuj',
    0xeea: 'Hangul_J_Cieuc',
    0xeeb: 'Hangul_J_Khieuq',
    0xeec: 'Hangul_J_Tieut',
    0xeed: 'Hangul_J_Phieuf',
    0xeee: 'Hangul_J_Hieuh',
    0xeef: 'Hangul_RieulYeorinHieuh',
    0xef0: 'Hangul_SunkyeongeumMieum',
    0xef1: 'Hangul_SunkyeongeumPieub',
    0xef2: 'Hangul_PanSios',
    0xef3: 'Hangul_KkogjiDalrinIeung',
    0xef4: 'Hangul_SunkyeongeumPhieuf',
    0xef5: 'Hangul_YeorinHieuh',
    0xef6: 'Hangul_AraeA',
    0xef7: 'Hangul_AraeAE',
    0xef8: 'Hangul_J_PanSios',
    0xef9: 'Hangul_J_KkogjiDalrinIeung',
    0xefa: 'Hangul_J_YeorinHieuh',
    0xeff: 'Korean_Won',
    0x10010d0: 'Georgian_an',
    0x10010d1: 'Georgian_ban',
    0x10010d2: 'Georgian_gan',
    0x10010d3: 'Georgian_don',
    0x10010d4: 'Georgian_en',
    0x10010d5: 'Georgian_vin',
    0x10010d6: 'Georgian_zen',
    0x10010d7: 'Georgian_tan',
    0x10010d8: 'Georgian_in',
    0x10010d9: 'Georgian_kan',
    0x10010da: 'Georgian_las',
    0x10010db: 'Georgian_man',
    0x10010dc: 'Georgian_nar',
    0x10010dd: 'Georgian_on',
    0x10010de: 'Georgian_par',
    0x10010df: 'Georgian_zhar',
    0x10010e0: 'Georgian_rae',
    0x10010e1: 'Georgian_san',
    0x10010e2: 'Georgian_tar',
    0x10010e3: 'Georgian_un',
    0x10010e4: 'Georgian_phar',
    0x10010e5: 'Georgian_khar',
    0x10010e6: 'Georgian_ghan',
    0x10010e7: 'Georgian_qar',
    0x10010e8: 'Georgian_shin',
    0x10010e9: 'Georgian_chin',
    0x10010ea: 'Georgian_can',
    0x10010eb: 'Georgian_jil',
    0x10010ec: 'Georgian_cil',
    0x10010ed: 'Georgian_char',
    0x10010ee: 'Georgian_xan',
    0x10010ef: 'Georgian_jhan',
    0x10010f0: 'Georgian_hae',
    0x10010f1: 'Georgian_he',
    0x10010f2: 'Georgian_hie',
    0x10010f3: 'Georgian_we',
    0x10010f4: 'Georgian_har',
    0x10010f5: 'Georgian_hoe',
    0x10010f6: 'Georgian_fi',
    0xda1: 'Thai_kokai',
    0xa1: 'exclamdown',
    0x13bc: 'OE',
    0x13bd: 'oe',
    0x13be: 'Ydiaeresis',
    0x10028a1: 'braille_dots_168',
    0x10028a2: 'braille_dots_268',
    0x8a3: 'horizconnector',
    0x10028a4: 'braille_dots_368',
    0x8a5: 'botintegral',
    0x10028a6: 'braille_dots_2368',
    0x8a7: 'topleftsqbracket',
    0x10028a8: 'braille_dots_468',
    0x10028a9: 'braille_dots_1468',
    0x8aa: 'botrightsqbracket',
    0x8ab: 'topleftparens',
    0x8ac: 'botleftparens',
    0x1001e02: 'Babovedot',
    0x10028ad: 'braille_dots_13468',
    0xfe03: 'ISO_Level3_Shift',
    0x8ae: 'botrightparens',
    0x10028af: 'braille_dots_123468',
    0x8b0: 'rightmiddlecurlybrace',
    0x10020a3: 'FFrancSign',
    0x8b1: 'topleftsummation',
    0x10028b2: 'braille_dots_2568',
    0x10028b3: 'braille_dots_12568',
    0x8b4: 'botvertsummationconnector',
    0xfe0a: 'ISO_Prev_Group',
    0x8b5: 'toprightsummation',
    0x1001e0b: 'dabovedot',
    0x10028b6: 'braille_dots_23568',
    0x10028b7: 'braille_dots_123568',
    0x10028bc: 'braille_dots_34568',
    0x10028bd: 'braille_dots_134568',
    0x10028be: 'braille_dots_234568',
    0x8bf: 'integral',
    0x10028c0: 'braille_dots_78',
    0x8c1: 'variation',
    0x8c2: 'infinity',
    0x8c5: 'nabla',
    0x10028c8: 'braille_dots_478',
    0x8c9: 'similarequal',
    0x8cd: 'ifonlyif',
    0x8ce: 'implies',
    0x8cf: 'identical',
    0x10028d6: 'braille_dots_23578',
    0x10028da: 'braille_dots_24578',
    0x10028db: 'braille_dots_124578',
    0x8dc: 'intersection',
    0x10028dd: 'braille_dots_134578',
    0x8de: 'logicaland',
    0x10028df: 'braille_dots_1234578',
    0x10028ef: 'braille_dots_1234678',
    0x8f6: 'function',
    0x10028fb: 'braille_dots_1245678',
    0x10028fc: 'braille_dots_345678',
    0x8fd: 'rightarrow',
    0x8fe: 'downarrow',
    0xfe56: 'dead_abovedot',
    0x1001e57: 'pabovedot',
    0x1001e60: 'Sabovedot',
    0x6c1: 'Cyrillic_a',
    0xfe61: 'dead_hook',
    0xfe6a: 'dead_belowtilde',
    0xfe6b: 'dead_belowbreve',
    0x1d1: 'Nacute',
    0x10006a9: 'Arabic_keheh',
    0x1d2: 'Ncaron',
    0x1001e80: 'Wgrave',
    0xfe81: 'dead_A',
    0xfe82: 'dead_e',
    0x1001e83: 'wacute',
    0x3d9: 'Uogonek',
    0x1001e84: 'Wdiaeresis',
    0x1001e85: 'wdiaeresis',
    0x1001e8a: 'Xabovedot',
    0xfe8b: 'dead_capital_schwa',
    0x3f1: 'ncedilla',
    0x3fd: 'utilde',
    0xfed0: 'First_Virtual_Screen',
    0xfed1: 'Prev_Virtual_Screen',
    0x1001ed2: 'Ocircumflexgrave',
    0xfed4: 'Last_Virtual_Screen',
    0x1001ed5: 'ocircumflexhook',
    0xfee0: 'Pointer_Left',
    0x1001ee1: 'ohorntilde',
    0xfee2: 'Pointer_Up',
    0xfee3: 'Pointer_Down',
    0xfee4: 'Pointer_UpLeft',
    0x1001ee5: 'ubelowdot',
    0xfee6: 'Pointer_DownLeft',
    0xfee7: 'Pointer_DownRight',
    0x1001ee8: 'Uhornacute',
    0xfee9: 'Pointer_Button1',
    0x1001eea: 'Uhorngrave',
    0xfeeb: 'Pointer_Button3',
    0x1001eec: 'Uhornhook',
    0x1001eed: 'uhornhook',
    0xfeee: 'Pointer_DblClick_Dflt',
    0xfeef: 'Pointer_DblClick1',
    0xfef0: 'Pointer_DblClick2',
    0xfef1: 'Pointer_DblClick3',
    0x1001ef2: 'Ygrave',
    0xfef3: 'Pointer_DblClick5',
    0xfef4: 'Pointer_Drag_Dflt',
    0x1001ef5: 'ybelowdot',
    0xfef6: 'Pointer_Drag2',
    0x1001ef7: 'yhook',
    0x1001ef8: 'Ytilde',
    0x1001ef9: 'ytilde',
    0x10004a2: 'Cyrillic_EN_descender',
    0x10004a3: 'Cyrillic_en_descender',
    0x4ae: 'kana_yo',
    0x10004af: 'Cyrillic_u_straight',
    0x10004b0: 'Cyrillic_U_straight_bar',
    0x10004b1: 'Cyrillic_u_straight_bar',
    0x10004b2: 'Cyrillic_HA_descender',
    0x10004b3: 'Cyrillic_ha_descender',
    0x4b6: 'kana_KA',
    0x4b7: 'kana_KI',
    0x4b8: 'kana_KU',
    0x4b9: 'kana_KE',
    0x4ba: 'kana_KO',
    0x4bb: 'kana_SA',
    0xfd01: '3270_Duplicate',
    0xfd02: '3270_FieldMark',
    0xfd03: '3270_Right2',
    0xfd04: '3270_Left2',
    0xfd05: '3270_BackTab',
    0xfd06: '3270_EraseEOF',
    0xfd07: '3270_EraseInput',
    0xfd08: '3270_Reset',
    0xfd09: '3270_Quit',
    0xfd0a: '3270_PA1',
    0xfd0b: '3270_PA2',
    0xfd0c: '3270_PA3',
    0xfd0d: '3270_Test',
    0xfd0e: '3270_Attn',
    0xfd0f: '3270_CursorBlink',
    0xfd10: '3270_AltCursor',
    0x4d8: 'kana_RI',
    0xfd12: '3270_Jump',
    0xfd13: '3270_Ident',
    0xfd14: '3270_Rule',
    0xfd15: '3270_Copy',
    0xfd16: '3270_Play',
    0x10004d9: 'Cyrillic_schwa',
    0xfd18: '3270_Record',
    0xfd19: '3270_ChangeScreen',
    0xfd1a: '3270_DeleteWord',
    0xfd1b: '3270_ExSelect',
    0xfd1c: '3270_CursorSelect',
    0xfd1d: '3270_PrintScreen',
    0xfd1e: '3270_Enter',
    0xfe01: 'ISO_Lock',
    0xfe02: 'ISO_Level2_Latch',
    0x1001e03: 'babovedot',
    0xfe04: 'ISO_Level3_Latch',
    0xfe05: 'ISO_Level3_Lock',
    0xfe06: 'ISO_Group_Latch',
    0xfe07: 'ISO_Group_Lock',
    0xfe08: 'ISO_Next_Group',
    0xfe09: 'ISO_Next_Group_Lock',
    0x1001e0a: 'Dabovedot',
    0xfe0b: 'ISO_Prev_Group_Lock',
    0xfe0c: 'ISO_First_Group',
    0xfe0d: 'ISO_First_Group_Lock',
    0xfe0e: 'ISO_Last_Group',
    0xfe0f: 'ISO_Last_Group_Lock',
    0xfe11: 'ISO_Level5_Shift',
    0xfe12: 'ISO_Level5_Latch',
    0xfe13: 'ISO_Level5_Lock',
    0x1001e1e: 'Fabovedot',
    0x1001e1f: 'fabovedot',
    0xfe20: 'ISO_Left_Tab',
    0xfe21: 'ISO_Move_Line_Up',
    0xfe22: 'ISO_Move_Line_Down',
    0xfe23: 'ISO_Partial_Line_Up',
    0xfe24: 'ISO_Partial_Line_Down',
    0xfe25: 'ISO_Partial_Space_Left',
    0xfe26: 'ISO_Partial_Space_Right',
    0xfe27: 'ISO_Set_Margin_Left',
    0xfe28: 'ISO_Set_Margin_Right',
    0xfe29: 'ISO_Release_Margin_Left',
    0xfe2a: 'ISO_Release_Margin_Right',
    0xfe2b: 'ISO_Release_Both_Margins',
    0xfe2c: 'ISO_Fast_Cursor_Left',
    0xfe2d: 'ISO_Fast_Cursor_Right',
    0xfe2e: 'ISO_Fast_Cursor_Up',
    0xfe2f: 'ISO_Fast_Cursor_Down',
    0xfe30: 'ISO_Continuous_Underline',
    0xfe31: 'ISO_Discontinuous_Underline',
    0xfe32: 'ISO_Emphasize',
    0xfe33: 'ISO_Center_Object',
    0xfe34: 'ISO_Enter',
    0x1001e36: 'Lbelowdot',
    0x1001e37: 'lbelowdot',
    0x1001e40: 'Mabovedot',
    0x1001e41: 'mabovedot',
    0xfe50: 'dead_grave',
    0xfe51: 'dead_acute',
    0xfe52: 'dead_circumflex',
    0xfe53: 'dead_tilde',
    0xfe54: 'dead_macron',
    0xfe55: 'dead_breve',
    0x1001e56: 'Pabovedot',
    0xfe57: 'dead_diaeresis',
    0xfe58: 'dead_abovering',
    0xfe59: 'dead_doubleacute',
    0xfe5a: 'dead_caron',
    0xfe5b: 'dead_cedilla',
    0xfe5c: 'dead_ogonek',
    0xfe5d: 'dead_iota',
    0xfe5e: 'dead_voiced_sound',
    0xfe5f: 'dead_semivoiced_sound',
    0xfe60: 'dead_belowdot',
    0x1001e61: 'sabovedot',
    0xfe62: 'dead_horn',
    0xfe63: 'dead_stroke',
    0xfe64: 'dead_abovecomma',
    0xfe65: 'dead_abovereversedcomma',
    0xfe66: 'dead_doublegrave',
    0xfe67: 'dead_belowring',
    0xfe68: 'dead_belowmacron',
    0xfe69: 'dead_belowcircumflex',
    0x1001e6a: 'Tabovedot',
    0x1001e6b: 'tabovedot',
    0xfe6c: 'dead_belowdiaeresis',
    0xfe6d: 'dead_invertedbreve',
    0xfe6e: 'dead_belowcomma',
    0xfe6f: 'dead_currency',
    0xfe70: 'AccessX_Enable',
    0xfe71: 'AccessX_Feedback_Enable',
    0xfe72: 'RepeatKeys_Enable',
    0xfe73: 'SlowKeys_Enable',
    0xfe74: 'BounceKeys_Enable',
    0xfe75: 'StickyKeys_Enable',
    0xfe76: 'MouseKeys_Enable',
    0xfe77: 'MouseKeys_Accel_Enable',
    0xfe78: 'Overlay1_Enable',
    0xfe79: 'Overlay2_Enable',
    0xfe7a: 'AudibleBell_Enable',
    0xfe80: 'dead_a',
    0x1001e81: 'wgrave',
    0x1001e82: 'Wacute',
    0xfe83: 'dead_E',
    0xfe84: 'dead_i',
    0xfe85: 'dead_I',
    0xfe86: 'dead_o',
    0xfe87: 'dead_O',
    0xfe88: 'dead_u',
    0xfe89: 'dead_U',
    0xfe8a: 'dead_small_schwa',
    0x1001e8b: 'xabovedot',
    0x1001ea0: 'Abelowdot',
    0x1001ea1: 'abelowdot',
    0x1001ea2: 'Ahook',
    0x1001ea3: 'ahook',
    0x1001ea4: 'Acircumflexacute',
    0x1001ea5: 'acircumflexacute',
    0x1001ea6: 'Acircumflexgrave',
    0x1001ea7: 'acircumflexgrave',
    0x1001ea8: 'Acircumflexhook',
    0x1001ea9: 'acircumflexhook',
    0x1001eaa: 'Acircumflextilde',
    0x1001eab: 'acircumflextilde',
    0x1001eac: 'Acircumflexbelowdot',
    0x1001ead: 'acircumflexbelowdot',
    0x1001eae: 'Abreveacute',
    0x1001eaf: 'abreveacute',
    0x1001eb0: 'Abrevegrave',
    0x1001eb1: 'abrevegrave',
    0x1001eb2: 'Abrevehook',
    0x1001eb3: 'abrevehook',
    0x1001eb4: 'Abrevetilde',
    0x1001eb5: 'abrevetilde',
    0x1001eb6: 'Abrevebelowdot',
    0x1001eb7: 'abrevebelowdot',
    0x1001eb8: 'Ebelowdot',
    0x1001eb9: 'ebelowdot',
    0x1001eba: 'Ehook',
    0x1001ebb: 'ehook',
    0x1001ebc: 'Etilde',
    0x1001ebd: 'etilde',
    0x1001ebe: 'Ecircumflexacute',
    0x1001ebf: 'ecircumflexacute',
    0x1001ec0: 'Ecircumflexgrave',
    0x1001ec1: 'ecircumflexgrave',
    0x1001ec2: 'Ecircumflexhook',
    0x1001ec3: 'ecircumflexhook',
    0x1001ec4: 'Ecircumflextilde',
    0x1001ec5: 'ecircumflextilde',
    0x1001ec6: 'Ecircumflexbelowdot',
    0x1001ec7: 'ecircumflexbelowdot',
    0x1001ec8: 'Ihook',
    0x1001ec9: 'ihook',
    0x1001eca: 'Ibelowdot',
    0x1001ecb: 'ibelowdot',
    0x1001ecc: 'Obelowdot',
    0x1001ecd: 'obelowdot',
    0x1001ece: 'Ohook',
    0x1001ecf: 'ohook',
    0x1001ed0: 'Ocircumflexacute',
    0x1001ed1: 'ocircumflexacute',
    0xfed2: 'Next_Virtual_Screen',
    0x1001ed3: 'ocircumflexgrave',
    0x1001ed4: 'Ocircumflexhook',
    0xfed5: 'Terminate_Server',
    0x1001ed6: 'Ocircumflextilde',
    0x1001ed7: 'ocircumflextilde',
    0x1001ed8: 'Ocircumflexbelowdot',
    0x1001ed9: 'ocircumflexbelowdot',
    0x1001eda: 'Ohornacute',
    0x1001edb: 'ohornacute',
    0x1001edc: 'Ohorngrave',
    0x1001edd: 'ohorngrave',
    0x1001ede: 'Ohornhook',
    0x1001edf: 'ohornhook',
    0x1001ee0: 'Ohorntilde',
    0xfee1: 'Pointer_Right',
    0x1001ee2: 'Ohornbelowdot',
    0x1001ee3: 'ohornbelowdot',
    0x1001ee4: 'Ubelowdot',
    0xfee5: 'Pointer_UpRight',
    0x1001ee6: 'Uhook',
    0x1001ee7: 'uhook',
    0xfee8: 'Pointer_Button_Dflt',
    0x1001ee9: 'uhornacute',
    0xfeea: 'Pointer_Button2',
    0x1001eeb: 'uhorngrave',
    0xfeec: 'Pointer_Button4',
    0xfeed: 'Pointer_Button5',
    0x1001eee: 'Uhorntilde',
    0x1001eef: 'uhorntilde',
    0x1001ef0: 'Uhornbelowdot',
    0x1001ef1: 'uhornbelowdot',
    0xfef2: 'Pointer_DblClick4',
    0x1001ef3: 'ygrave',
    0x1001ef4: 'Ybelowdot',
    0xfef5: 'Pointer_Drag1',
    0x1001ef6: 'Yhook',
    0xfef7: 'Pointer_Drag3',
    0xfef8: 'Pointer_Drag4',
    0xfef9: 'Pointer_EnableKeys',
    0xfefa: 'Pointer_Accelerate',
    0xfefb: 'Pointer_DfltBtnNext',
    0xfefc: 'Pointer_DfltBtnPrev',
    0xfefd: 'Pointer_Drag5',
    0xff08: 'BackSpace',
    0xff09: 'Tab',
    0xff0a: 'Linefeed',
    0xff0b: 'Clear',
    0xff0d: 'Return',
    0xff13: 'Pause',
    0xff14: 'Scroll_Lock',
    0xff15: 'Sys_Req',
    0xff1b: 'Escape',
    0xff20: 'Multi_key',
    0xff21: 'Kanji',
    0xff22: 'Muhenkan',
    0xff23: 'Henkan',
    0xff24: 'Romaji',
    0xff25: 'Hiragana',
    0xff26: 'Katakana',
    0xff27: 'Hiragana_Katakana',
    0xff28: 'Zenkaku',
    0xff29: 'Hankaku',
    0xff2a: 'Zenkaku_Hankaku',
    0xff2b: 'Touroku',
    0xff2c: 'Massyo',
    0xff2d: 'Kana_Lock',
    0xff2e: 'Kana_Shift',
    0xff2f: 'Eisu_Shift',
    0xff30: 'Eisu_toggle',
    0xff31: 'Hangul',
    0xff32: 'Hangul_Start',
    0xff33: 'Hangul_End',
    0xff34: 'Hangul_Hanja',
    0xff35: 'Hangul_Jamo',
    0xff36: 'Hangul_Romaja',
    0xff37: 'Kanji_Bangou',
    0xff38: 'Hangul_Jeonja',
    0xff39: 'Hangul_Banja',
    0xff3a: 'Hangul_PreHanja',
    0xff3b: 'Hangul_PostHanja',
    0xff3c: 'Hangul_SingleCandidate',
    0xff3d: 'Hangul_MultipleCandidate',
    0xff3e: 'Hangul_PreviousCandidate',
    0xff3f: 'Hangul_Special',
    0xff50: 'Home',
    0xff51: 'Left',
    0xff52: 'Up',
    0xff53: 'Right',
    0xff54: 'Down',
    0xff55: 'Prior',
    0xff56: 'Next',
    0xff57: 'End',
    0xff58: 'Begin',
    0xff60: 'Select',
    0xff61: 'Print',
    0xff62: 'Execute',
    0xff63: 'Insert',
    0xff65: 'Undo',
    0xff66: 'Redo',
    0xff67: 'Menu',
    0xff68: 'Find',
    0xff69: 'Cancel',
    0xff6a: 'Help',
    0xff6b: 'Break',
    0xff7e: 'Arabic_switch',
    0xff7f: 'Num_Lock',
    0xff80: 'KP_Space',
    0xff89: 'KP_Tab',
    0xff8d: 'KP_Enter',
    0xff91: 'KP_F1',
    0xff92: 'KP_F2',
    0xff93: 'KP_F3',
    0xff94: 'KP_F4',
    0xff95: 'KP_Home',
    0xff96: 'KP_Left',
    0xff97: 'KP_Up',
    0xff98: 'KP_Right',
    0xff99: 'KP_Down',
    0xff9a: 'KP_Prior',
    0xff9b: 'KP_Page_Down',
    0xff9c: 'KP_End',
    0xff9d: 'KP_Begin',
    0xff9e: 'KP_Insert',
    0xff9f: 'KP_Delete',
    0xffaa: 'KP_Multiply',
    0xffab: 'KP_Add',
    0xffac: 'KP_Separator',
    0xffad: 'KP_Subtract',
    0xffae: 'KP_Decimal',
    0xffaf: 'KP_Divide',
    0xffb0: 'KP_0',
    0xffb1: 'KP_1',
    0xffb2: 'KP_2',
    0xffb3: 'KP_3',
    0xffb4: 'KP_4',
    0xffb5: 'KP_5',
    0xffb6: 'KP_6',
    0xffb7: 'KP_7',
    0xffb8: 'KP_8',
    0xffb9: 'KP_9',
    0xffbd: 'KP_Equal',
    0xffbe: 'F1',
    0xffbf: 'F2',
    0xffc0: 'F3',
    0xffc1: 'F4',
    0xffc2: 'F5',
    0xffc3: 'F6',
    0xffc4: 'F7',
    0xffc5: 'F8',
    0xffc6: 'F9',
    0xffc7: 'F10',
    0xffc8: 'F11',
    0xffc9: 'F12',
    0xffca: 'F13',
    0xffcb: 'F14',
    0xffcc: 'F15',
    0xffcd: 'F16',
    0xffce: 'F17',
    0xffcf: 'F18',
    0xffd0: 'F19',
    0xffd1: 'L10',
    0xffd2: 'R1',
    0xffd3: 'R2',
    0xffd4: 'R3',
    0xffd5: 'F24',
    0xffd6: 'R5',
    0xffd7: 'R6',
    0xffd8: 'R7',
    0xffd9: 'R8',
    0xffda: 'R9',
    0xffdb: 'R10',
    0xffdc: 'R11',
    0xffdd: 'R12',
    0xffde: 'R13',
    0xffdf: 'R14',
    0xffe0: 'R15',
    0xffe1: 'Shift_L',
    0xffe2: 'Shift_R',
    0xffe3: 'Control_L',
    0xffe4: 'Control_R',
    0xffe5: 'Caps_Lock',
    0xffe6: 'Shift_Lock',
    0xffe7: 'Meta_L',
    0xffe8: 'Meta_R',
    0xffe9: 'Alt_L',
    0xffea: 'Alt_R',
    0xffeb: 'Super_L',
    0xffec: 'Super_R',
    0xffed: 'Hyper_L',
    0xffee: 'Hyper_R',
    0xfff1: 'braille_dot_1',
    0xfff2: 'braille_dot_2',
    0xfff3: 'braille_dot_3',
    0xfff4: 'braille_dot_4',
    0xfff5: 'braille_dot_5',
    0xfff6: 'braille_dot_6',
    0xfff7: 'braille_dot_7',
    0xfff8: 'braille_dot_8',
    0xfff9: 'braille_dot_9',
    0xfffa: 'braille_dot_10',
    0xffffff: 'VoidSymbol',
    0xffff: 'Delete',
}

legacy_keysyms = {
    0x01A1: 0x0104,
    0x01A2: 0x02D8,
    0x01A3: 0x0141,
    0x01A5: 0x013D,
    0x01A6: 0x015A,
    0x01A9: 0x0160,
    0x01AA: 0x015E,
    0x01AB: 0x0164,
    0x01AC: 0x0179,
    0x01AE: 0x017D,
    0x01AF: 0x017B,
    0x01B1: 0x0105,
    0x01B2: 0x02DB,
    0x01B3: 0x0142,
    0x01B5: 0x013E,
    0x01B6: 0x015B,
    0x01B7: 0x02C7,
    0x01B9: 0x0161,
    0x01BA: 0x015F,
    0x01BB: 0x0165,
    0x01BC: 0x017A,
    0x01BD: 0x02DD,
    0x01BE: 0x017E,
    0x01BF: 0x017C,
    0x01C0: 0x0154,
    0x01C3: 0x0102,
    0x01C5: 0x0139,
    0x01C6: 0x0106,
    0x01C8: 0x010C,
    0x01CA: 0x0118,
    0x01CC: 0x011A,
    0x01CF: 0x010E,
    0x01D0: 0x0110,
    0x01D1: 0x0143,
    0x01D2: 0x0147,
    0x01D5: 0x0150,
    0x01D8: 0x0158,
    0x01D9: 0x016E,
    0x01DB: 0x0170,
    0x01DE: 0x0162,
    0x01E0: 0x0155,
    0x01E3: 0x0103,
    0x01E5: 0x013A,
    0x01E6: 0x0107,
    0x01E8: 0x010D,
    0x01EA: 0x0119,
    0x01EC: 0x011B,
    0x01EF: 0x010F,
    0x01F0: 0x0111,
    0x01F1: 0x0144,
    0x01F2: 0x0148,
    0x01F5: 0x0151,
    0x01F8: 0x0159,
    0x01F9: 0x016F,
    0x01FB: 0x0171,
    0x01FE: 0x0163,
    0x01FF: 0x02D9,
    0x02A1: 0x0126,
    0x02A6: 0x0124,
    0x02A9: 0x0130,
    0x02AB: 0x011E,
    0x02AC: 0x0134,
    0x02B1: 0x0127,
    0x02B6: 0x0125,
    0x02B9: 0x0131,
    0x02BB: 0x011F,
    0x02BC: 0x0135,
    0x02C5: 0x010A,
    0x02C6: 0x0108,
    0x02D5: 0x0120,
    0x02D8: 0x011C,
    0x02DD: 0x016C,
    0x02DE: 0x015C,
    0x02E5: 0x010B,
    0x02E6: 0x0109,
    0x02F5: 0x0121,
    0x02F8: 0x011D,
    0x02FD: 0x016D,
    0x02FE: 0x015D,
    0x03A2: 0x0138,
    0x03A3: 0x0156,
    0x03A5: 0x0128,
    0x03A6: 0x013B,
    0x03AA: 0x0112,
    0x03AB: 0x0122,
    0x03AC: 0x0166,
    0x03B3: 0x0157,
    0x03B5: 0x0129,
    0x03B6: 0x013C,
    0x03BA: 0x0113,
    0x03BB: 0x0123,
    0x03BC: 0x0167,
    0x03BD: 0x014A,
    0x03BF: 0x014B,
    0x03C0: 0x0100,
    0x03C7: 0x012E,
    0x03CC: 0x0116,
    0x03CF: 0x012A,
    0x03D1: 0x0145,
    0x03D2: 0x014C,
    0x03D3: 0x0136,
    0x03D9: 0x0172,
    0x03DD: 0x0168,
    0x03DE: 0x016A,
    0x03E0: 0x0101,
    0x03E7: 0x012F,
    0x03EC: 0x0117,
    0x03EF: 0x012B,
    0x03F1: 0x0146,
    0x03F2: 0x014D,
    0x03F3: 0x0137,
    0x03F9: 0x0173,
    0x03FD: 0x0169,
    0x03FE: 0x016B,
    0x047E: 0x203E,
    0x04A1: 0x3002,
    0x04A2: 0x300C,
    0x04A3: 0x300D,
    0x04A4: 0x3001,
    0x04A5: 0x30FB,
    0x04A6: 0x30F2,
    0x04A7: 0x30A1,
    0x04A8: 0x30A3,
    0x04A9: 0x30A5,
    0x04AA: 0x30A7,
    0x04AB: 0x30A9,
    0x04AC: 0x30E3,
    0x04AD: 0x30E5,
    0x04AE: 0x30E7,
    0x04AF: 0x30C3,
    0x04B0: 0x30FC,
    0x04B1: 0x30A2,
    0x04B2: 0x30A4,
    0x04B3: 0x30A6,
    0x04B4: 0x30A8,
    0x04B5: 0x30AA,
    0x04B6: 0x30AB,
    0x04B7: 0x30AD,
    0x04B8: 0x30AF,
    0x04B9: 0x30B1,
    0x04BA: 0x30B3,
    0x04BB: 0x30B5,
    0x04BC: 0x30B7,
    0x04BD: 0x30B9,
    0x04BE: 0x30BB,
    0x04BF: 0x30BD,
    0x04C0: 0x30BF,
    0x04C1: 0x30C1,
    0x04C2: 0x30C4,
    0x04C3: 0x30C6,
    0x04C4: 0x30C8,
    0x04C5: 0x30CA,
    0x04C6: 0x30CB,
    0x04C7: 0x30CC,
    0x04C8: 0x30CD,
    0x04C9: 0x30CE,
    0x04CA: 0x30CF,
    0x04CB: 0x30D2,
    0x04CC: 0x30D5,
    0x04CD: 0x30D8,
    0x04CE: 0x30DB,
    0x04CF: 0x30DE,
    0x04D0: 0x30DF,
    0x04D1: 0x30E0,
    0x04D2: 0x30E1,
    0x04D3: 0x30E2,
    0x04D4: 0x30E4,
    0x04D5: 0x30E6,
    0x04D6: 0x30E8,
    0x04D7: 0x30E9,
    0x04D8: 0x30EA,
    0x04D9: 0x30EB,
    0x04DA: 0x30EC,
    0x04DB: 0x30ED,
    0x04DC: 0x30EF,
    0x04DD: 0x30F3,
    0x04DE: 0x309B,
    0x04DF: 0x309C,
    0x05AC: 0x060C,
    0x05BB: 0x061B,
    0x05BF: 0x061F,
    0x05C1: 0x0621,
    0x05C2: 0x0622,
    0x05C3: 0x0623,
    0x05C4: 0x0624,
    0x05C5: 0x0625,
    0x05C6: 0x0626,
    0x05C7: 0x0627,
    0x05C8: 0x0628,
    0x05C9: 0x0629,
    0x05CA: 0x062A,
    0x05CB: 0x062B,
    0x05CC: 0x062C,
    0x05CD: 0x062D,
    0x05CE: 0x062E,
    0x05CF: 0x062F,
    0x05D0: 0x0630,
    0x05D1: 0x0631,
    0x05D2: 0x0632,
    0x05D3: 0x0633,
    0x05D4: 0x0634,
    0x05D5: 0x0635,
    0x05D6: 0x0636,
    0x05D7: 0x0637,
    0x05D8: 0x0638,
    0x05D9: 0x0639,
    0x05DA: 0x063A,
    0x05E0: 0x0640,
    0x05E1: 0x0641,
    0x05E2: 0x0642,
    0x05E3: 0x0643,
    0x05E4: 0x0644,
    0x05E5: 0x0645,
    0x05E6: 0x0646,
    0x05E7: 0x0647,
    0x05E8: 0x0648,
    0x05E9: 0x0649,
    0x05EA: 0x064A,
    0x05EB: 0x064B,
    0x05EC: 0x064C,
    0x05ED: 0x064D,
    0x05EE: 0x064E,
    0x05EF: 0x064F,
    0x05F0: 0x0650,
    0x05F1: 0x0651,
    0x05F2: 0x0652,
    0x06A1: 0x0452,
    0x06A2: 0x0453,
    0x06A3: 0x0451,
    0x06A4: 0x0454,
    0x06A5: 0x0455,
    0x06A6: 0x0456,
    0x06A7: 0x0457,
    0x06A8: 0x0458,
    0x06A9: 0x0459,
    0x06AA: 0x045A,
    0x06AB: 0x045B,
    0x06AC: 0x045C,
    0x06AD: 0x0491,
    0x06AE: 0x045E,
    0x06AF: 0x045F,
    0x06B0: 0x2116,
    0x06B1: 0x0402,
    0x06B2: 0x0403,
    0x06B3: 0x0401,
    0x06B4: 0x0404,
    0x06B5: 0x0405,
    0x06B6: 0x0406,
    0x06B7: 0x0407,
    0x06B8: 0x0408,
    0x06B9: 0x0409,
    0x06BA: 0x040A,
    0x06BB: 0x040B,
    0x06BC: 0x040C,
    0x06BD: 0x0490,
    0x06BE: 0x040E,
    0x06BF: 0x040F,
    0x06C0: 0x044E,
    0x06C1: 0x0430,
    0x06C2: 0x0431,
    0x06C3: 0x0446,
    0x06C4: 0x0434,
    0x06C5: 0x0435,
    0x06C6: 0x0444,
    0x06C7: 0x0433,
    0x06C8: 0x0445,
    0x06C9: 0x0438,
    0x06CA: 0x0439,
    0x06CB: 0x043A,
    0x06CC: 0x043B,
    0x06CD: 0x043C,
    0x06CE: 0x043D,
    0x06CF: 0x043E,
    0x06D0: 0x043F,
    0x06D1: 0x044F,
    0x06D2: 0x0440,
    0x06D3: 0x0441,
    0x06D4: 0x0442,
    0x06D5: 0x0443,
    0x06D6: 0x0436,
    0x06D7: 0x0432,
    0x06D8: 0x044C,
    0x06D9: 0x044B,
    0x06DA: 0x0437,
    0x06DB: 0x0448,
    0x06DC: 0x044D,
    0x06DD: 0x0449,
    0x06DE: 0x0447,
    0x06DF: 0x044A,
    0x06E0: 0x042E,
    0x06E1: 0x0410,
    0x06E2: 0x0411,
    0x06E3: 0x0426,
    0x06E4: 0x0414,
    0x06E5: 0x0415,
    0x06E6: 0x0424,
    0x06E7: 0x0413,
    0x06E8: 0x0425,
    0x06E9: 0x0418,
    0x06EA: 0x0419,
    0x06EB: 0x041A,
    0x06EC: 0x041B,
    0x06ED: 0x041C,
    0x06EE: 0x041D,
    0x06EF: 0x041E,
    0x06F0: 0x041F,
    0x06F1: 0x042F,
    0x06F2: 0x0420,
    0x06F3: 0x0421,
    0x06F4: 0x0422,
    0x06F5: 0x0423,
    0x06F6: 0x0416,
    0x06F7: 0x0412,
    0x06F8: 0x042C,
    0x06F9: 0x042B,
    0x06FA: 0x0417,
    0x06FB: 0x0428,
    0x06FC: 0x042D,
    0x06FD: 0x0429,
    0x06FE: 0x0427,
    0x06FF: 0x042A,
    0x07A1: 0x0386,
    0x07A2: 0x0388,
    0x07A3: 0x0389,
    0x07A4: 0x038A,
    0x07A5: 0x03AA,
    0x07A7: 0x038C,
    0x07A8: 0x038E,
    0x07A9: 0x03AB,
    0x07AB: 0x038F,
    0x07AE: 0x0385,
    0x07AF: 0x2015,
    0x07B1: 0x03AC,
    0x07B2: 0x03AD,
    0x07B3: 0x03AE,
    0x07B4: 0x03AF,
    0x07B5: 0x03CA,
    0x07B6: 0x0390,
    0x07B7: 0x03CC,
    0x07B8: 0x03CD,
    0x07B9: 0x03CB,
    0x07BA: 0x03B0,
    0x07BB: 0x03CE,
    0x07C1: 0x0391,
    0x07C2: 0x0392,
    0x07C3: 0x0393,
    0x07C4: 0x0394,
    0x07C5: 0x0395,
    0x07C6: 0x0396,
    0x07C7: 0x0397,
    0x07C8: 0x0398,
    0x07C9: 0x0399,
    0x07CA: 0x039A,
    0x07CB: 0x039B,
    0x07CC: 0x039C,
    0x07CD: 0x039D,
    0x07CE: 0x039E,
    0x07CF: 0x039F,
    0x07D0: 0x03A0,
    0x07D1: 0x03A1,
    0x07D2: 0x03A3,
    0x07D4: 0x03A4,
    0x07D5: 0x03A5,
    0x07D6: 0x03A6,
    0x07D7: 0x03A7,
    0x07D8: 0x03A8,
    0x07D9: 0x03A9,
    0x07E1: 0x03B1,
    0x07E2: 0x03B2,
    0x07E3: 0x03B3,
    0x07E4: 0x03B4,
    0x07E5: 0x03B5,
    0x07E6: 0x03B6,
    0x07E7: 0x03B7,
    0x07E8: 0x03B8,
    0x07E9: 0x03B9,
    0x07EA: 0x03BA,
    0x07EB: 0x03BB,
    0x07EC: 0x03BC,
    0x07ED: 0x03BD,
    0x07EE: 0x03BE,
    0x07EF: 0x03BF,
    0x07F0: 0x03C0,
    0x07F1: 0x03C1,
    0x07F2: 0x03C3,
    0x07F3: 0x03C2,
    0x07F4: 0x03C4,
    0x07F5: 0x03C5,
    0x07F6: 0x03C6,
    0x07F7: 0x03C7,
    0x07F8: 0x03C8,
    0x07F9: 0x03C9,
    0x08A1: 0x23B7,
    0x08A4: 0x2320,
    0x08A5: 0x2321,
    0x08A7: 0x23A1,
    0x08A8: 0x23A3,
    0x08A9: 0x23A4,
    0x08AA: 0x23A6,
    0x08AB: 0x239B,
    0x08AC: 0x239D,
    0x08AD: 0x239E,
    0x08AE: 0x23A0,
    0x08AF: 0x23A8,
    0x08B0: 0x23AC,
    0x08BC: 0x2264,
    0x08BD: 0x2260,
    0x08BE: 0x2265,
    0x08BF: 0x222B,
    0x08C0: 0x2234,
    0x08C1: 0x221D,
    0x08C2: 0x221E,
    0x08C5: 0x2207,
    0x08C8: 0x223C,
    0x08C9: 0x2243,
    0x08CD: 0x21D4,
    0x08CE: 0x21D2,
    0x08CF: 0x2261,
    0x08D6: 0x221A,
    0x08DA: 0x2282,
    0x08DB: 0x2283,
    0x08DC: 0x2229,
    0x08DD: 0x222A,
    0x08DE: 0x2227,
    0x08DF: 0x2228,
    0x08EF: 0x2202,
    0x08F6: 0x0192,
    0x08FB: 0x2190,
    0x08FC: 0x2191,
    0x08FD: 0x2192,
    0x08FE: 0x2193,
    0x09E0: 0x25C6,
    0x09E1: 0x2592,
    0x09E2: 0x2409,
    0x09E3: 0x240C,
    0x09E4: 0x240D,
    0x09E5: 0x240A,
    0x09E8: 0x2424,
    0x09E9: 0x240B,
    0x09EA: 0x2518,
    0x09EB: 0x2510,
    0x09EC: 0x250C,
    0x09ED: 0x2514,
    0x09EE: 0x253C,
    0x09EF: 0x23BA,
    0x09F0: 0x23BB,
    0x09F1: 0x2500,
    0x09F2: 0x23BC,
    0x09F3: 0x23BD,
    0x09F4: 0x251C,
    0x09F5: 0x2524,
    0x09F6: 0x2534,
    0x09F7: 0x252C,
    0x09F8: 0x2502,
    0x0AA1: 0x2003,
    0x0AA2: 0x2002,
    0x0AA3: 0x2004,
    0x0AA4: 0x2005,
    0x0AA5: 0x2007,
    0x0AA6: 0x2008,
    0x0AA7: 0x2009,
    0x0AA8: 0x200A,
    0x0AA9: 0x2014,
    0x0AAA: 0x2013,
    0x0AAE: 0x2026,
    0x0AAF: 0x2025,
    0x0AB0: 0x2153,
    0x0AB1: 0x2154,
    0x0AB2: 0x2155,
    0x0AB3: 0x2156,
    0x0AB4: 0x2157,
    0x0AB5: 0x2158,
    0x0AB6: 0x2159,
    0x0AB7: 0x215A,
    0x0AB8: 0x2105,
    0x0ABB: 0x2012,
    0x0AC3: 0x215B,
    0x0AC4: 0x215C,
    0x0AC5: 0x215D,
    0x0AC6: 0x215E,
    0x0AC9: 0x2122,
    0x0AD0: 0x2018,
    0x0AD1: 0x2019,
    0x0AD2: 0x201C,
    0x0AD3: 0x201D,
    0x0AD4: 0x211E,
    0x0AD6: 0x2032,
    0x0AD7: 0x2033,
    0x0AD9: 0x271D,
    0x0AEC: 0x2663,
    0x0AED: 0x2666,
    0x0AEE: 0x2665,
    0x0AF0: 0x2720,
    0x0AF1: 0x2020,
    0x0AF2: 0x2021,
    0x0AF3: 0x2713,
    0x0AF4: 0x2717,
    0x0AF5: 0x266F,
    0x0AF6: 0x266D,
    0x0AF7: 0x2642,
    0x0AF8: 0x2640,
    0x0AF9: 0x260E,
    0x0AFA: 0x2315,
    0x0AFB: 0x2117,
    0x0AFC: 0x2038,
    0x0AFD: 0x201A,
    0x0AFE: 0x201E,
    0x0BC2: 0x22A5,
    0x0BC4: 0x230A,
    0x0BCA: 0x2218,
    0x0BCC: 0x2395,
    0x0BCE: 0x22A4,
    0x0BCF: 0x25CB,
    0x0BD3: 0x2308,
    0x0BDC: 0x22A2,
    0x0BFC: 0x22A3,
    0x0CDF: 0x2017,
    0x0CE0: 0x05D0,
    0x0CE1: 0x05D1,
    0x0CE2: 0x05D2,
    0x0CE3: 0x05D3,
    0x0CE4: 0x05D4,
    0x0CE5: 0x05D5,
    0x0CE6: 0x05D6,
    0x0CE7: 0x05D7,
    0x0CE8: 0x05D8,
    0x0CE9: 0x05D9,
    0x0CEA: 0x05DA,
    0x0CEB: 0x05DB,
    0x0CEC: 0x05DC,
    0x0CED: 0x05DD,
    0x0CEE: 0x05DE,
    0x0CEF: 0x05DF,
    0x0CF0: 0x05E0,
    0x0CF1: 0x05E1,
    0x0CF2: 0x05E2,
    0x0CF3: 0x05E3,
    0x0CF4: 0x05E4,
    0x0CF5: 0x05E5,
    0x0CF6: 0x05E6,
    0x0CF7: 0x05E7,
    0x0CF8: 0x05E8,
    0x0CF9: 0x05E9,
    0x0CFA: 0x05EA,
    0x0DA1: 0x0E01,
    0x0DA2: 0x0E02,
    0x0DA3: 0x0E03,
    0x0DA4: 0x0E04,
    0x0DA5: 0x0E05,
    0x0DA6: 0x0E06,
    0x0DA7: 0x0E07,
    0x0DA8: 0x0E08,
    0x0DA9: 0x0E09,
    0x0DAA: 0x0E0A,
    0x0DAB: 0x0E0B,
    0x0DAC: 0x0E0C,
    0x0DAD: 0x0E0D,
    0x0DAE: 0x0E0E,
    0x0DAF: 0x0E0F,
    0x0DB0: 0x0E10,
    0x0DB1: 0x0E11,
    0x0DB2: 0x0E12,
    0x0DB3: 0x0E13,
    0x0DB4: 0x0E14,
    0x0DB5: 0x0E15,
    0x0DB6: 0x0E16,
    0x0DB7: 0x0E17,
    0x0DB8: 0x0E18,
    0x0DB9: 0x0E19,
    0x0DBA: 0x0E1A,
    0x0DBB: 0x0E1B,
    0x0DBC: 0x0E1C,
    0x0DBD: 0x0E1D,
    0x0DBE: 0x0E1E,
    0x0DBF: 0x0E1F,
    0x0DC0: 0x0E20,
    0x0DC1: 0x0E21,
    0x0DC2: 0x0E22,
    0x0DC3: 0x0E23,
    0x0DC4: 0x0E24,
    0x0DC5: 0x0E25,
    0x0DC6: 0x0E26,
    0x0DC7: 0x0E27,
    0x0DC8: 0x0E28,
    0x0DC9: 0x0E29,
    0x0DCA: 0x0E2A,
    0x0DCB: 0x0E2B,
    0x0DCC: 0x0E2C,
    0x0DCD: 0x0E2D,
    0x0DCE: 0x0E2E,
    0x0DCF: 0x0E2F,
    0x0DD0: 0x0E30,
    0x0DD1: 0x0E31,
    0x0DD2: 0x0E32,
    0x0DD3: 0x0E33,
    0x0DD4: 0x0E34,
    0x0DD5: 0x0E35,
    0x0DD6: 0x0E36,
    0x0DD7: 0x0E37,
    0x0DD8: 0x0E38,
    0x0DD9: 0x0E39,
    0x0DDA: 0x0E3A,
    0x0DDF: 0x0E3F,
    0x0DE0: 0x0E40,
    0x0DE1: 0x0E41,
    0x0DE2: 0x0E42,
    0x0DE3: 0x0E43,
    0x0DE4: 0x0E44,
    0x0DE5: 0x0E45,
    0x0DE6: 0x0E46,
    0x0DE7: 0x0E47,
    0x0DE8: 0x0E48,
    0x0DE9: 0x0E49,
    0x0DEA: 0x0E4A,
    0x0DEB: 0x0E4B,
    0x0DEC: 0x0E4C,
    0x0DED: 0x0E4D,
    0x0DF0: 0x0E50,
    0x0DF1: 0x0E51,
    0x0DF2: 0x0E52,
    0x0DF3: 0x0E53,
    0x0DF4: 0x0E54,
    0x0DF5: 0x0E55,
    0x0DF6: 0x0E56,
    0x0DF7: 0x0E57,
    0x0DF8: 0x0E58,
    0x0DF9: 0x0E59,
    0x13BC: 0x0152,
    0x13BD: 0x0153,
    0x13BE: 0x0178,
    0x20AC: 0x20AC,
}
